from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Storage.Vhd
import win32more.Windows.Win32.Storage.VirtualDiskService
import win32more.Windows.Win32.System.Com
VDS_NF_VOLUME_ARRIVE: UInt32 = 4
VDS_NF_VOLUME_DEPART: UInt32 = 5
VDS_NF_VOLUME_MODIFY: UInt32 = 6
VDS_NF_VOLUME_REBUILDING_PROGRESS: UInt32 = 7
VDS_NF_PARTITION_ARRIVE: UInt32 = 11
VDS_NF_PARTITION_DEPART: UInt32 = 12
VDS_NF_PARTITION_MODIFY: UInt32 = 13
VDS_NF_SUB_SYSTEM_ARRIVE: UInt32 = 101
VDS_NF_SUB_SYSTEM_DEPART: UInt32 = 102
VDS_NF_PORTAL_ARRIVE: UInt32 = 123
VDS_NF_PORTAL_DEPART: UInt32 = 124
VDS_NF_PORTAL_MODIFY: UInt32 = 125
VDS_NF_TARGET_ARRIVE: UInt32 = 126
VDS_NF_TARGET_DEPART: UInt32 = 127
VDS_NF_TARGET_MODIFY: UInt32 = 128
VDS_NF_PORTAL_GROUP_ARRIVE: UInt32 = 129
VDS_NF_PORTAL_GROUP_DEPART: UInt32 = 130
VDS_NF_PORTAL_GROUP_MODIFY: UInt32 = 131
VDS_NF_SUB_SYSTEM_MODIFY: UInt32 = 151
VDS_NF_DRIVE_LETTER_FREE: UInt32 = 201
VDS_NF_DRIVE_LETTER_ASSIGN: UInt32 = 202
VDS_NF_MOUNT_POINTS_CHANGE: UInt32 = 205
VDS_NF_FILE_SYSTEM_SHRINKING_PROGRESS: UInt32 = 206
VDS_NF_SERVICE_OUT_OF_SYNC: UInt32 = 301
GPT_PARTITION_NAME_LENGTH: UInt32 = 36
VDS_HINT_FASTCRASHRECOVERYREQUIRED: Int32 = 1
VDS_HINT_MOSTLYREADS: Int32 = 2
VDS_HINT_OPTIMIZEFORSEQUENTIALREADS: Int32 = 4
VDS_HINT_OPTIMIZEFORSEQUENTIALWRITES: Int32 = 8
VDS_HINT_READBACKVERIFYENABLED: Int32 = 16
VDS_HINT_REMAPENABLED: Int32 = 32
VDS_HINT_WRITETHROUGHCACHINGENABLED: Int32 = 64
VDS_HINT_HARDWARECHECKSUMENABLED: Int32 = 128
VDS_HINT_ISYANKABLE: Int32 = 256
VDS_HINT_ALLOCATEHOTSPARE: Int32 = 512
VDS_HINT_BUSTYPE: Int32 = 1024
VDS_HINT_USEMIRROREDCACHE: Int32 = 2048
VDS_HINT_READCACHINGENABLED: Int32 = 4096
VDS_HINT_WRITECACHINGENABLED: Int32 = 8192
VDS_HINT_MEDIASCANENABLED: Int32 = 16384
VDS_HINT_CONSISTENCYCHECKENABLED: Int32 = 32768
VDS_REBUILD_PRIORITY_MIN: UInt32 = 0
VDS_REBUILD_PRIORITY_MAX: UInt32 = 16
VDS_POOL_ATTRIB_RAIDTYPE: Int32 = 1
VDS_POOL_ATTRIB_BUSTYPE: Int32 = 2
VDS_POOL_ATTRIB_ALLOW_SPINDOWN: Int32 = 4
VDS_POOL_ATTRIB_THIN_PROVISION: Int32 = 8
VDS_POOL_ATTRIB_NO_SINGLE_POF: Int32 = 16
VDS_POOL_ATTRIB_DATA_RDNCY_MAX: Int32 = 32
VDS_POOL_ATTRIB_DATA_RDNCY_MIN: Int32 = 64
VDS_POOL_ATTRIB_DATA_RDNCY_DEF: Int32 = 128
VDS_POOL_ATTRIB_PKG_RDNCY_MAX: Int32 = 256
VDS_POOL_ATTRIB_PKG_RDNCY_MIN: Int32 = 512
VDS_POOL_ATTRIB_PKG_RDNCY_DEF: Int32 = 1024
VDS_POOL_ATTRIB_STRIPE_SIZE: Int32 = 2048
VDS_POOL_ATTRIB_STRIPE_SIZE_MAX: Int32 = 4096
VDS_POOL_ATTRIB_STRIPE_SIZE_MIN: Int32 = 8192
VDS_POOL_ATTRIB_STRIPE_SIZE_DEF: Int32 = 16384
VDS_POOL_ATTRIB_NUM_CLMNS: Int32 = 32768
VDS_POOL_ATTRIB_NUM_CLMNS_MAX: Int32 = 65536
VDS_POOL_ATTRIB_NUM_CLMNS_MIN: Int32 = 131072
VDS_POOL_ATTRIB_NUM_CLMNS_DEF: Int32 = 262144
VDS_POOL_ATTRIB_DATA_AVL_HINT: Int32 = 524288
VDS_POOL_ATTRIB_ACCS_RNDM_HINT: Int32 = 1048576
VDS_POOL_ATTRIB_ACCS_DIR_HINT: Int32 = 2097152
VDS_POOL_ATTRIB_ACCS_SIZE_HINT: Int32 = 4194304
VDS_POOL_ATTRIB_ACCS_LTNCY_HINT: Int32 = 8388608
VDS_POOL_ATTRIB_ACCS_BDW_WT_HINT: Int32 = 16777216
VDS_POOL_ATTRIB_STOR_COST_HINT: Int32 = 33554432
VDS_POOL_ATTRIB_STOR_EFFCY_HINT: Int32 = 67108864
VDS_POOL_ATTRIB_CUSTOM_ATTRIB: Int32 = 134217728
VDS_ATTACH_VIRTUAL_DISK_FLAG_USE_FILE_ACL: UInt32 = 1
CLSID_VdsLoader: Guid = Guid('{9c38ed61-d565-4728-aeee-c80952f0ecde}')
CLSID_VdsService: Guid = Guid('{7d1933cb-86f6-4a98-8628-01be94c9a575}')
MAX_FS_NAME_SIZE: UInt32 = 8
MAX_FS_FORMAT_SUPPORT_NAME_SIZE: UInt32 = 32
MAX_FS_ALLOWED_CLUSTER_SIZES_SIZE: UInt32 = 32
VER_VDS_LUN_INFORMATION: UInt32 = 1
VDS_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212288
VDS_E_INITIALIZED_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212287
VDS_E_INITIALIZE_NOT_CALLED: win32more.Windows.Win32.Foundation.HRESULT = -2147212286
VDS_E_ALREADY_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147212285
VDS_E_ANOTHER_CALL_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147212284
VDS_E_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147212283
VDS_E_INVALID_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147212282
VDS_E_PARTITION_LIMIT_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147212281
VDS_E_PARTITION_NOT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2147212280
VDS_E_OPERATION_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2147212279
VDS_E_OPERATION_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147212278
VDS_E_OBJECT_DELETED: win32more.Windows.Win32.Foundation.HRESULT = -2147212277
VDS_E_CANCEL_TOO_LATE: win32more.Windows.Win32.Foundation.HRESULT = -2147212276
VDS_E_OPERATION_CANCELED: win32more.Windows.Win32.Foundation.HRESULT = -2147212275
VDS_E_CANNOT_EXTEND: win32more.Windows.Win32.Foundation.HRESULT = -2147212274
VDS_E_NOT_ENOUGH_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147212273
VDS_E_NOT_ENOUGH_DRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147212272
VDS_E_BAD_COOKIE: win32more.Windows.Win32.Foundation.HRESULT = -2147212271
VDS_E_NO_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -2147212270
VDS_E_DEVICE_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2147212269
VDS_E_DISK_NOT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2147212268
VDS_E_INVALID_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2147212267
VDS_E_PATH_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147212266
VDS_E_DISK_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2147212265
VDS_E_NOT_AN_UNALLOCATED_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147212264
VDS_E_UNRECOVERABLE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147212263
VDS_S_DISK_PARTIALLY_CLEANED: win32more.Windows.Win32.Foundation.HRESULT = 271386
VDS_E_DMADMIN_SERVICE_CONNECTION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212261
VDS_E_PROVIDER_INITIALIZATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212260
VDS_E_OBJECT_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147212259
VDS_E_NO_DISKS_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147212258
VDS_E_PROVIDER_CACHE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147212257
VDS_E_DMADMIN_METHOD_CALL_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212256
VDS_S_PROVIDER_ERROR_LOADING_CACHE: win32more.Windows.Win32.Foundation.HRESULT = 271393
VDS_E_PROVIDER_VOL_DEVICE_NAME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147212254
VDS_E_PROVIDER_VOL_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147212253
VDS_E_DMADMIN_CORRUPT_NOTIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -2147212252
VDS_E_INCOMPATIBLE_FILE_SYSTEM: win32more.Windows.Win32.Foundation.HRESULT = -2147212251
VDS_E_INCOMPATIBLE_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -2147212250
VDS_E_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2147212249
VDS_E_MEDIA_WRITE_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212248
VDS_E_BAD_LABEL: win32more.Windows.Win32.Foundation.HRESULT = -2147212247
VDS_E_CANT_QUICK_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147212246
VDS_E_IO_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147212245
VDS_E_VOLUME_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147212244
VDS_E_VOLUME_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2147212243
VDS_E_CLUSTER_SIZE_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147212242
VDS_E_CLUSTER_SIZE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2147212241
VDS_E_CLUSTER_COUNT_BEYOND_32BITS: win32more.Windows.Win32.Foundation.HRESULT = -2147212240
VDS_E_OBJECT_STATUS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212239
VDS_E_VOLUME_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2147212238
VDS_E_EXTENT_SIZE_LESS_THAN_MIN: win32more.Windows.Win32.Foundation.HRESULT = -2147212237
VDS_S_UPDATE_BOOTFILE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271412
VDS_S_BOOT_PARTITION_NUMBER_CHANGE: win32more.Windows.Win32.Foundation.HRESULT = 271414
VDS_E_BOOT_PARTITION_NUMBER_CHANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147212234
VDS_E_NO_FREE_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147212233
VDS_E_ACTIVE_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = -2147212232
VDS_E_PARTITION_OF_UNKNOWN_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147212231
VDS_E_LEGACY_VOLUME_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2147212230
VDS_E_NON_CONTIGUOUS_DATA_PARTITIONS: win32more.Windows.Win32.Foundation.HRESULT = -2147212229
VDS_E_MIGRATE_OPEN_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2147212228
VDS_E_VOLUME_NOT_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147212227
VDS_E_VOLUME_NOT_HEALTHY: win32more.Windows.Win32.Foundation.HRESULT = -2147212226
VDS_E_VOLUME_SPANS_DISKS: win32more.Windows.Win32.Foundation.HRESULT = -2147212225
VDS_E_REQUIRES_CONTIGUOUS_DISK_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147212224
VDS_E_BAD_PROVIDER_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147212223
VDS_E_PROVIDER_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147212222
VDS_S_VOLUME_COMPRESS_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271427
VDS_E_PACK_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147212220
VDS_E_VOLUME_NOT_A_MIRROR: win32more.Windows.Win32.Foundation.HRESULT = -2147212219
VDS_E_NO_EXTENTS_FOR_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2147212218
VDS_E_DISK_NOT_LOADED_TO_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2147212217
VDS_E_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147212216
VDS_S_ACCESS_PATH_NOT_DELETED: win32more.Windows.Win32.Foundation.HRESULT = 279108
VDS_E_PROVIDER_TYPE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212214
VDS_E_DISK_NOT_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147212213
VDS_E_DISK_IN_USE_BY_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2147212212
VDS_S_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = 271437
VDS_E_ASYNC_OBJECT_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2147212210
VDS_E_VOLUME_NOT_MOUNTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212209
VDS_E_PACK_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147212208
VDS_E_IMPORT_SET_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2147212207
VDS_E_DISK_NOT_IMPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212206
VDS_E_OBJECT_OUT_OF_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147212205
VDS_E_MISSING_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147212204
VDS_E_DISK_PNP_REG_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147212203
VDS_E_LBN_REMAP_ENABLED_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147212202
VDS_E_NO_DRIVELETTER_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147212201
VDS_E_REVERT_ON_CLOSE: win32more.Windows.Win32.Foundation.HRESULT = -2147212200
VDS_E_REVERT_ON_CLOSE_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147212199
VDS_E_IA64_BOOT_MIRRORED_TO_MBR: win32more.Windows.Win32.Foundation.HRESULT = -2147212198
VDS_S_IA64_BOOT_MIRRORED_TO_MBR: win32more.Windows.Win32.Foundation.HRESULT = 271450
VDS_S_UNABLE_TO_GET_GPT_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = 271451
VDS_E_VOLUME_TEMPORARILY_DISMOUNTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212196
VDS_E_VOLUME_PERMANENTLY_DISMOUNTED: win32more.Windows.Win32.Foundation.HRESULT = -2147212195
VDS_E_VOLUME_HAS_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2147212194
VDS_E_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147212193
VDS_E_REPAIR_VOLUMESTATE: win32more.Windows.Win32.Foundation.HRESULT = -2147212192
VDS_E_LDM_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147212191
VDS_E_REVERT_ON_CLOSE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147212190
VDS_E_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2147212189
VDS_E_ONLINE_PACK_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2147212188
VDS_S_EXTEND_FILE_SYSTEM_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271461
VDS_E_EXTEND_FILE_SYSTEM_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147212186
VDS_S_MBR_BOOT_MIRRORED_TO_GPT: win32more.Windows.Win32.Foundation.HRESULT = 271463
VDS_E_MAX_USABLE_MBR: win32more.Windows.Win32.Foundation.HRESULT = -2147212184
VDS_S_GPT_BOOT_MIRRORED_TO_MBR: win32more.Windows.Win32.Foundation.HRESULT = -2147212183
VDS_E_NO_SOFTWARE_PROVIDERS_LOADED: win32more.Windows.Win32.Foundation.HRESULT = -2147212032
VDS_E_DISK_NOT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2147212031
VDS_E_NO_VOLUME_LAYOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147212030
VDS_E_CORRUPT_VOLUME_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147212029
VDS_E_INVALID_ENUMERATOR: win32more.Windows.Win32.Foundation.HRESULT = -2147212028
VDS_E_DRIVER_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147212027
VDS_E_VOLUME_INVALID_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147212025
VDS_S_DISK_IS_MISSING: win32more.Windows.Win32.Foundation.HRESULT = 271624
VDS_E_CORRUPT_PARTITION_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147212023
VDS_S_NONCONFORMANT_PARTITION_INFO: win32more.Windows.Win32.Foundation.HRESULT = 271626
VDS_E_CORRUPT_EXTENT_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147212021
VDS_E_DUP_EMPTY_PACK_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147212020
VDS_E_DRIVER_NO_PACK_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147212019
VDS_S_SYSTEM_PARTITION: win32more.Windows.Win32.Foundation.HRESULT = 271630
VDS_E_BAD_PNP_MESSAGE: win32more.Windows.Win32.Foundation.HRESULT = -2147212017
VDS_E_NO_PNP_DISK_ARRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147212016
VDS_E_NO_PNP_VOLUME_ARRIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147212015
VDS_E_NO_PNP_DISK_REMOVE: win32more.Windows.Win32.Foundation.HRESULT = -2147212014
VDS_E_NO_PNP_VOLUME_REMOVE: win32more.Windows.Win32.Foundation.HRESULT = -2147212013
VDS_E_PROVIDER_EXITING: win32more.Windows.Win32.Foundation.HRESULT = -2147212012
VDS_E_EXTENT_EXCEEDS_DISK_FREE_SPACE: win32more.Windows.Win32.Foundation.HRESULT = -2147212011
VDS_E_MEMBER_SIZE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147212010
VDS_S_NO_NOTIFICATION: win32more.Windows.Win32.Foundation.HRESULT = 271639
VDS_S_DEFAULT_PLEX_MEMBER_IDS: win32more.Windows.Win32.Foundation.HRESULT = 271640
VDS_E_INVALID_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147212007
VDS_E_INVALID_PACK: win32more.Windows.Win32.Foundation.HRESULT = -2147212006
VDS_E_VOLUME_ON_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147212005
VDS_E_DRIVER_INVALID_PARAM: win32more.Windows.Win32.Foundation.HRESULT = -2147212004
VDS_E_TARGET_PACK_NOT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2147212003
VDS_E_CANNOT_SHRINK: win32more.Windows.Win32.Foundation.HRESULT = -2147212002
VDS_E_MULTIPLE_PACKS: win32more.Windows.Win32.Foundation.HRESULT = -2147212001
VDS_E_PACK_ONLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147212000
VDS_E_INVALID_PLEX_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147211999
VDS_E_INVALID_MEMBER_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147211998
VDS_E_INVALID_PLEX_ORDER: win32more.Windows.Win32.Foundation.HRESULT = -2147211997
VDS_E_INVALID_MEMBER_ORDER: win32more.Windows.Win32.Foundation.HRESULT = -2147211996
VDS_E_INVALID_STRIPE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147211995
VDS_E_INVALID_DISK_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147211994
VDS_E_INVALID_EXTENT_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147211993
VDS_E_SOURCE_IS_TARGET_PACK: win32more.Windows.Win32.Foundation.HRESULT = -2147211992
VDS_E_VOLUME_DISK_COUNT_MAX_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2147211991
VDS_E_CORRUPT_NOTIFICATION_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147211990
VDS_E_INVALID_PLEX_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147211988
VDS_E_DISK_NOT_FOUND_IN_PACK: win32more.Windows.Win32.Foundation.HRESULT = -2147211987
VDS_E_DUPLICATE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211986
VDS_E_LAST_VALID_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211985
VDS_E_INVALID_SECTOR_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147211984
VDS_E_ONE_EXTENT_PER_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211983
VDS_E_INVALID_BLOCK_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147211982
VDS_E_PLEX_SIZE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147211981
VDS_E_NO_EXTENTS_FOR_PLEX: win32more.Windows.Win32.Foundation.HRESULT = -2147211980
VDS_E_INVALID_PLEX_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211979
VDS_E_INVALID_PLEX_BLOCK_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147211978
VDS_E_NO_HEALTHY_DISKS: win32more.Windows.Win32.Foundation.HRESULT = -2147211977
VDS_E_CONFIG_LIMIT: win32more.Windows.Win32.Foundation.HRESULT = -2147211976
VDS_E_DISK_CONFIGURATION_CORRUPTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211975
VDS_E_DISK_CONFIGURATION_NOT_IN_SYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147211974
VDS_E_DISK_CONFIGURATION_UPDATE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147211973
VDS_E_DISK_DYNAMIC: win32more.Windows.Win32.Foundation.HRESULT = -2147211972
VDS_E_DRIVER_OBJECT_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147211971
VDS_E_PARTITION_NOT_CYLINDER_ALIGNED: win32more.Windows.Win32.Foundation.HRESULT = -2147211970
VDS_E_DISK_LAYOUT_PARTITIONS_TOO_SMALL: win32more.Windows.Win32.Foundation.HRESULT = -2147211969
VDS_E_DISK_IO_FAILING: win32more.Windows.Win32.Foundation.HRESULT = -2147211968
VDS_E_DYNAMIC_DISKS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211967
VDS_E_FAULT_TOLERANT_DISKS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211966
VDS_E_GPT_ATTRIBUTES_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147211965
VDS_E_MEMBER_IS_HEALTHY: win32more.Windows.Win32.Foundation.HRESULT = -2147211964
VDS_E_MEMBER_REGENERATING: win32more.Windows.Win32.Foundation.HRESULT = -2147211963
VDS_E_PACK_NAME_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147211962
VDS_E_PLEX_IS_HEALTHY: win32more.Windows.Win32.Foundation.HRESULT = -2147211961
VDS_E_PLEX_LAST_ACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -2147211960
VDS_E_PLEX_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2147211959
VDS_E_MEMBER_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2147211958
VDS_E_PLEX_REGENERATING: win32more.Windows.Win32.Foundation.HRESULT = -2147211957
VDS_E_UNEXPECTED_DISK_LAYOUT_CHANGE: win32more.Windows.Win32.Foundation.HRESULT = -2147211955
VDS_E_INVALID_VOLUME_LENGTH: win32more.Windows.Win32.Foundation.HRESULT = -2147211954
VDS_E_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE: win32more.Windows.Win32.Foundation.HRESULT = -2147211953
VDS_E_VOLUME_NOT_RETAINED: win32more.Windows.Win32.Foundation.HRESULT = -2147211952
VDS_E_VOLUME_RETAINED: win32more.Windows.Win32.Foundation.HRESULT = -2147211951
VDS_E_ALIGN_BEYOND_FIRST_CYLINDER: win32more.Windows.Win32.Foundation.HRESULT = -2147211949
VDS_E_ALIGN_NOT_SECTOR_SIZE_MULTIPLE: win32more.Windows.Win32.Foundation.HRESULT = -2147211948
VDS_E_ALIGN_NOT_ZERO: win32more.Windows.Win32.Foundation.HRESULT = -2147211947
VDS_E_CACHE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147211946
VDS_E_CANNOT_CLEAR_VOLUME_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147211945
VDS_E_DISK_BEING_CLEANED: win32more.Windows.Win32.Foundation.HRESULT = -2147211944
VDS_E_DISK_NOT_CONVERTIBLE: win32more.Windows.Win32.Foundation.HRESULT = -2147211943
VDS_E_DISK_REMOVEABLE: win32more.Windows.Win32.Foundation.HRESULT = -2147211942
VDS_E_DISK_REMOVEABLE_NOT_EMPTY: win32more.Windows.Win32.Foundation.HRESULT = -2147211941
VDS_E_DRIVE_LETTER_NOT_FREE: win32more.Windows.Win32.Foundation.HRESULT = -2147211940
VDS_E_EXTEND_MULTIPLE_DISKS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211939
VDS_E_INVALID_DRIVE_LETTER: win32more.Windows.Win32.Foundation.HRESULT = -2147211938
VDS_E_INVALID_DRIVE_LETTER_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2147211937
VDS_E_INVALID_FS_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147211936
VDS_E_INVALID_FS_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211935
VDS_E_INVALID_OBJECT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211934
VDS_E_INVALID_PARTITION_LAYOUT: win32more.Windows.Win32.Foundation.HRESULT = -2147211933
VDS_E_INVALID_PARTITION_STYLE: win32more.Windows.Win32.Foundation.HRESULT = -2147211932
VDS_E_INVALID_PARTITION_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211931
VDS_E_INVALID_PROVIDER_CLSID: win32more.Windows.Win32.Foundation.HRESULT = -2147211930
VDS_E_INVALID_PROVIDER_ID: win32more.Windows.Win32.Foundation.HRESULT = -2147211929
VDS_E_INVALID_PROVIDER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147211928
VDS_E_INVALID_PROVIDER_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211927
VDS_E_INVALID_PROVIDER_VERSION_GUID: win32more.Windows.Win32.Foundation.HRESULT = -2147211926
VDS_E_INVALID_PROVIDER_VERSION_STRING: win32more.Windows.Win32.Foundation.HRESULT = -2147211925
VDS_E_INVALID_QUERY_PROVIDER_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147211924
VDS_E_INVALID_SERVICE_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147211923
VDS_E_INVALID_VOLUME_FLAG: win32more.Windows.Win32.Foundation.HRESULT = -2147211922
VDS_E_PARTITION_NOT_OEM: win32more.Windows.Win32.Foundation.HRESULT = -2147211921
VDS_E_PARTITION_PROTECTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211920
VDS_E_PARTITION_STYLE_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2147211919
VDS_E_PROVIDER_INTERNAL_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147211918
VDS_E_SHRINK_SIZE_LESS_THAN_MIN: win32more.Windows.Win32.Foundation.HRESULT = -2147211917
VDS_E_SHRINK_SIZE_TOO_BIG: win32more.Windows.Win32.Foundation.HRESULT = -2147211916
VDS_E_UNRECOVERABLE_PROVIDER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147211915
VDS_E_VOLUME_HIDDEN: win32more.Windows.Win32.Foundation.HRESULT = -2147211914
VDS_S_DISMOUNT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271735
VDS_S_REMOUNT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271736
VDS_E_FLAG_ALREADY_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147211911
VDS_S_RESYNC_NOTIFICATION_TASK_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 271738
VDS_E_DISTINCT_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2147211909
VDS_E_VOLUME_NOT_FOUND_IN_PACK: win32more.Windows.Win32.Foundation.HRESULT = -2147211908
VDS_E_PARTITION_NON_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147211907
VDS_E_CRITICAL_PLEX: win32more.Windows.Win32.Foundation.HRESULT = -2147211906
VDS_E_VOLUME_SYNCHRONIZING: win32more.Windows.Win32.Foundation.HRESULT = -2147211905
VDS_E_VOLUME_REGENERATING: win32more.Windows.Win32.Foundation.HRESULT = -2147211904
VDS_S_VSS_FLUSH_AND_HOLD_WRITES: win32more.Windows.Win32.Foundation.HRESULT = 271745
VDS_S_VSS_RELEASE_WRITES: win32more.Windows.Win32.Foundation.HRESULT = 271746
VDS_S_FS_LOCK: win32more.Windows.Win32.Foundation.HRESULT = 271747
VDS_E_READONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147211900
VDS_E_INVALID_VOLUME_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2147211899
VDS_E_BAD_BOOT_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211898
VDS_E_LOG_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2147211897
VDS_E_VOLUME_MIRRORED: win32more.Windows.Win32.Foundation.HRESULT = -2147211896
VDS_E_VOLUME_SIMPLE_SPANNED: win32more.Windows.Win32.Foundation.HRESULT = -2147211895
VDS_E_NO_VALID_LOG_COPIES: win32more.Windows.Win32.Foundation.HRESULT = -2147211894
VDS_S_PLEX_NOT_LOADED_TO_CACHE: win32more.Windows.Win32.Foundation.HRESULT = 271755
VDS_E_PLEX_NOT_LOADED_TO_CACHE: win32more.Windows.Win32.Foundation.HRESULT = -2147211893
VDS_E_PARTITION_MSR: win32more.Windows.Win32.Foundation.HRESULT = -2147211892
VDS_E_PARTITION_LDM: win32more.Windows.Win32.Foundation.HRESULT = -2147211891
VDS_S_WINPE_BOOTENTRY: win32more.Windows.Win32.Foundation.HRESULT = 271758
VDS_E_ALIGN_NOT_A_POWER_OF_TWO: win32more.Windows.Win32.Foundation.HRESULT = -2147211889
VDS_E_ALIGN_IS_ZERO: win32more.Windows.Win32.Foundation.HRESULT = -2147211888
VDS_E_SHRINK_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147211887
VDS_E_CANT_INVALIDATE_FVE: win32more.Windows.Win32.Foundation.HRESULT = -2147211886
VDS_E_FS_NOT_DETERMINED: win32more.Windows.Win32.Foundation.HRESULT = -2147211885
VDS_E_DISK_NOT_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147211883
VDS_E_FAILED_TO_ONLINE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211882
VDS_E_FAILED_TO_OFFLINE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211881
VDS_E_BAD_REVISION_NUMBER: win32more.Windows.Win32.Foundation.HRESULT = -2147211880
VDS_E_SHRINK_USER_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2147211879
VDS_E_SHRINK_DIRTY_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2147211878
VDS_S_NAME_TRUNCATED: win32more.Windows.Win32.Foundation.HRESULT = 272128
VDS_E_NAME_NOT_UNIQUE: win32more.Windows.Win32.Foundation.HRESULT = -2147211519
VDS_S_STATUSES_INCOMPLETELY_SET: win32more.Windows.Win32.Foundation.HRESULT = 272130
VDS_E_ADDRESSES_INCOMPLETELY_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147211517
VDS_E_SECURITY_INCOMPLETELY_SET: win32more.Windows.Win32.Foundation.HRESULT = -2147211515
VDS_E_TARGET_SPECIFIC_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211514
VDS_E_INITIATOR_SPECIFIC_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147211513
VDS_E_ISCSI_LOGIN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147211512
VDS_E_ISCSI_LOGOUT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147211511
VDS_E_ISCSI_SESSION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147211510
VDS_E_ASSOCIATED_LUNS_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2147211509
VDS_E_ASSOCIATED_PORTALS_EXIST: win32more.Windows.Win32.Foundation.HRESULT = -2147211508
VDS_E_NO_DISCOVERY_DOMAIN: win32more.Windows.Win32.Foundation.HRESULT = -2147211507
VDS_E_MULTIPLE_DISCOVERY_DOMAINS: win32more.Windows.Win32.Foundation.HRESULT = -2147211506
VDS_E_NO_DISK_PATHNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147211505
VDS_E_ISCSI_LOGOUT_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = -2147211504
VDS_E_NO_VOLUME_PATHNAME: win32more.Windows.Win32.Foundation.HRESULT = -2147211503
VDS_E_PROVIDER_CACHE_OUTOFSYNC: win32more.Windows.Win32.Foundation.HRESULT = -2147211502
VDS_E_NO_IMPORT_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2147211501
VDS_S_ALREADY_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = 272148
VDS_S_PROPERTIES_INCOMPLETE: win32more.Windows.Win32.Foundation.HRESULT = 272149
VDS_S_ISCSI_SESSION_NOT_FOUND_PERSISTENT_LOGIN_REMOVED: win32more.Windows.Win32.Foundation.HRESULT = 272384
VDS_S_ISCSI_PERSISTENT_LOGIN_MAY_NOT_BE_REMOVED: win32more.Windows.Win32.Foundation.HRESULT = 272385
VDS_S_ISCSI_LOGIN_ALREAD_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = 272386
VDS_E_UNABLE_TO_FIND_BOOT_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211261
VDS_E_INCORRECT_BOOT_VOLUME_EXTENT_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147211260
VDS_E_GET_SAN_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2147211259
VDS_E_SET_SAN_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2147211258
VDS_E_BOOT_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211257
VDS_S_DISK_MOUNT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 272392
VDS_S_DISK_DISMOUNT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = 272393
VDS_E_DISK_IS_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147211254
VDS_E_DISK_IS_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147211253
VDS_E_PAGEFILE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211252
VDS_E_HIBERNATION_FILE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211251
VDS_E_CRASHDUMP_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211250
VDS_E_UNABLE_TO_FIND_SYSTEM_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211249
VDS_E_INCORRECT_SYSTEM_VOLUME_EXTENT_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147211248
VDS_E_SYSTEM_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147211247
VDS_E_VOLUME_SHRINK_FVE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2147211246
VDS_E_VOLUME_SHRINK_FVE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147211245
VDS_E_VOLUME_SHRINK_FVE_RECOVERY: win32more.Windows.Win32.Foundation.HRESULT = -2147211244
VDS_E_VOLUME_SHRINK_FVE: win32more.Windows.Win32.Foundation.HRESULT = -2147211243
VDS_E_SHRINK_OVER_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147211242
VDS_E_INVALID_SHRINK_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147211241
VDS_E_LUN_DISK_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2147211240
VDS_E_LUN_DISK_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147211239
VDS_E_LUN_DISK_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2147211238
VDS_E_LUN_DISK_NO_MEDIA: win32more.Windows.Win32.Foundation.HRESULT = -2147211237
VDS_E_LUN_NOT_READY: win32more.Windows.Win32.Foundation.HRESULT = -2147211236
VDS_E_LUN_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147211235
VDS_E_LUN_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2147211234
VDS_E_VOLUME_EXTEND_FVE_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2147211233
VDS_E_VOLUME_EXTEND_FVE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2147211232
VDS_E_VOLUME_EXTEND_FVE_RECOVERY: win32more.Windows.Win32.Foundation.HRESULT = -2147211231
VDS_E_VOLUME_EXTEND_FVE: win32more.Windows.Win32.Foundation.HRESULT = -2147211230
VDS_E_SECTOR_SIZE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2147211229
VDS_E_INITIATOR_ADAPTER_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147211008
VDS_E_TARGET_PORTAL_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2147211007
VDS_E_INVALID_PORT_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2147211006
VDS_E_INVALID_ISCSI_TARGET_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147211005
VDS_E_SET_TUNNEL_MODE_OUTER_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147211004
VDS_E_ISCSI_GET_IKE_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147211003
VDS_E_ISCSI_SET_IKE_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2147211002
VDS_E_SUBSYSTEM_ID_IS_NULL: win32more.Windows.Win32.Foundation.HRESULT = -2147211001
VDS_E_ISCSI_INITIATOR_NODE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2147211000
VDS_E_ISCSI_GROUP_PRESHARE_KEY: win32more.Windows.Win32.Foundation.HRESULT = -2147210999
VDS_E_ISCSI_CHAP_SECRET: win32more.Windows.Win32.Foundation.HRESULT = -2147210998
VDS_E_INVALID_IP_ADDRESS: win32more.Windows.Win32.Foundation.HRESULT = -2147210997
VDS_E_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2147210996
VDS_E_VOLUME_GUID_PATHNAME_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2147210995
VDS_E_BOOT_PAGEFILE_DRIVE_LETTER: win32more.Windows.Win32.Foundation.HRESULT = -2147210994
VDS_E_DELETE_WITH_CRITICAL: win32more.Windows.Win32.Foundation.HRESULT = -2147210993
VDS_E_CLEAN_WITH_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2147210992
VDS_E_CLEAN_WITH_OEM: win32more.Windows.Win32.Foundation.HRESULT = -2147210991
VDS_E_CLEAN_WITH_CRITICAL: win32more.Windows.Win32.Foundation.HRESULT = -2147210990
VDS_E_FORMAT_CRITICAL: win32more.Windows.Win32.Foundation.HRESULT = -2147210989
VDS_E_NTFS_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210988
VDS_E_FAT32_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210987
VDS_E_FAT_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210986
VDS_E_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210985
VDS_E_COMPRESSION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210984
VDS_E_VDISK_NOT_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147210983
VDS_E_VDISK_INVALID_OP_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2147210982
VDS_E_INVALID_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2147210981
VDS_E_INVALID_ISCSI_PATH: win32more.Windows.Win32.Foundation.HRESULT = -2147210980
VDS_E_SHRINK_LUN_NOT_UNMASKED: win32more.Windows.Win32.Foundation.HRESULT = -2147210979
VDS_E_LUN_DISK_READ_ONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147210978
VDS_E_LUN_UPDATE_DISK: win32more.Windows.Win32.Foundation.HRESULT = -2147210977
VDS_E_LUN_DYNAMIC: win32more.Windows.Win32.Foundation.HRESULT = -2147210976
VDS_E_LUN_DYNAMIC_OFFLINE: win32more.Windows.Win32.Foundation.HRESULT = -2147210975
VDS_E_LUN_SHRINK_GPT_HEADER: win32more.Windows.Win32.Foundation.HRESULT = -2147210974
VDS_E_MIRROR_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210973
VDS_E_RAID5_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210972
VDS_E_DISK_NOT_CONVERTIBLE_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2147210971
VDS_E_OFFLINE_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210970
VDS_E_VDISK_PATHNAME_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2147210969
VDS_E_EXTEND_TOO_MANY_CLUSTERS: win32more.Windows.Win32.Foundation.HRESULT = -2147210968
VDS_E_EXTEND_UNKNOWN_FILESYSTEM: win32more.Windows.Win32.Foundation.HRESULT = -2147210967
VDS_E_SHRINK_UNKNOWN_FILESYSTEM: win32more.Windows.Win32.Foundation.HRESULT = -2147210966
VDS_E_VD_DISK_NOT_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147210965
VDS_E_VD_DISK_IS_EXPANDING: win32more.Windows.Win32.Foundation.HRESULT = -2147210964
VDS_E_VD_DISK_IS_COMPACTING: win32more.Windows.Win32.Foundation.HRESULT = -2147210963
VDS_E_VD_DISK_IS_MERGING: win32more.Windows.Win32.Foundation.HRESULT = -2147210962
VDS_E_VD_IS_ATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147210961
VDS_E_VD_DISK_ALREADY_OPEN: win32more.Windows.Win32.Foundation.HRESULT = -2147210960
VDS_E_VD_DISK_ALREADY_EXPANDING: win32more.Windows.Win32.Foundation.HRESULT = -2147210959
VDS_E_VD_ALREADY_COMPACTING: win32more.Windows.Win32.Foundation.HRESULT = -2147210958
VDS_E_VD_ALREADY_MERGING: win32more.Windows.Win32.Foundation.HRESULT = -2147210957
VDS_E_VD_ALREADY_ATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147210956
VDS_E_VD_ALREADY_DETACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147210955
VDS_E_VD_NOT_ATTACHED_READONLY: win32more.Windows.Win32.Foundation.HRESULT = -2147210954
VDS_E_VD_IS_BEING_ATTACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147210953
VDS_E_VD_IS_BEING_DETACHED: win32more.Windows.Win32.Foundation.HRESULT = -2147210952
VDS_E_NO_POOL: win32more.Windows.Win32.Foundation.HRESULT = -2147210752
VDS_E_NO_POOL_CREATED: win32more.Windows.Win32.Foundation.HRESULT = -2147210751
VDS_E_NO_MAINTENANCE_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2147210750
VDS_E_BLOCK_CLUSTERED: win32more.Windows.Win32.Foundation.HRESULT = -2147210749
VDS_E_DISK_HAS_BANDS: win32more.Windows.Win32.Foundation.HRESULT = -2147210748
VDS_E_INVALID_STATE: win32more.Windows.Win32.Foundation.HRESULT = -2147210747
VDS_E_REFS_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2147210746
VDS_E_DELETE_WITH_BOOTBACKING: win32more.Windows.Win32.Foundation.HRESULT = -2147210745
VDS_E_FORMAT_WITH_BOOTBACKING: win32more.Windows.Win32.Foundation.HRESULT = -2147210744
VDS_E_CLEAN_WITH_BOOTBACKING: win32more.Windows.Win32.Foundation.HRESULT = -2147210743
VDS_E_SHRINK_EXTEND_UNALIGNED: win32more.Windows.Win32.Foundation.HRESULT = -2147210496
class CHANGE_ATTRIBUTES_PARAMETERS(Structure):
    style: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        MbrPartInfo: _MbrPartInfo_e__Struct
        GptPartInfo: _GptPartInfo_e__Struct
        class _MbrPartInfo_e__Struct(Structure):
            bootIndicator: win32more.Windows.Win32.Foundation.BOOLEAN
        class _GptPartInfo_e__Struct(Structure):
            attributes: UInt64
class CHANGE_PARTITION_TYPE_PARAMETERS(Structure):
    style: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        MbrPartInfo: _MbrPartInfo_e__Struct
        GptPartInfo: _GptPartInfo_e__Struct
        class _MbrPartInfo_e__Struct(Structure):
            partitionType: Byte
        class _GptPartInfo_e__Struct(Structure):
            partitionType: Guid
class CREATE_PARTITION_PARAMETERS(Structure):
    style: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        MbrPartInfo: _MbrPartInfo_e__Struct
        GptPartInfo: _GptPartInfo_e__Struct
        class _MbrPartInfo_e__Struct(Structure):
            partitionType: Byte
            bootIndicator: win32more.Windows.Win32.Foundation.BOOLEAN
        class _GptPartInfo_e__Struct(Structure):
            partitionType: Guid
            partitionId: Guid
            attributes: UInt64
            name: Char * 36
class IEnumVdsObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{118610b7-8d94-4030-b5b8-500889788e4e}')
    @commethod(3)
    def Next(self, celt: UInt32, ppObjectArray: POINTER(win32more.Windows.Win32.System.Com.IUnknown), pcFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Skip(self, celt: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAdmin(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d188e97d-85aa-4d33-abc6-26299a10ffc1}')
    @commethod(3)
    def RegisterProvider(self, providerId: Guid, providerClsid: Guid, pwszName: win32more.Windows.Win32.Foundation.PWSTR, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE, pwszMachineName: win32more.Windows.Win32.Foundation.PWSTR, pwszVersion: win32more.Windows.Win32.Foundation.PWSTR, guidVersionId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnregisterProvider(self, providerId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAdvancedDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6e6f6b40-977c-4069-bddd-ac710059f8c0}')
    @commethod(3)
    def GetPartitionProperties(self, ullOffset: UInt64, pPartitionProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryPartitions(self, ppPartitionPropArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_PROP)), plNumberOfPartitions: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreatePartition(self, ullOffset: UInt64, ullSize: UInt64, para: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.CREATE_PARTITION_PARAMETERS), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def DeletePartition(self, ullOffset: UInt64, bForce: win32more.Windows.Win32.Foundation.BOOL, bForceProtected: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ChangeAttributes(self, ullOffset: UInt64, para: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.CHANGE_ATTRIBUTES_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AssignDriveLetter(self, ullOffset: UInt64, wcLetter: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def DeleteDriveLetter(self, ullOffset: UInt64, wcLetter: Char) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetDriveLetter(self, ullOffset: UInt64, pwcLetter: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def FormatPartition(self, ullOffset: UInt64, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, dwUnitAllocationSize: UInt32, bForce: win32more.Windows.Win32.Foundation.BOOL, bQuickFormat: win32more.Windows.Win32.Foundation.BOOL, bEnableCompression: win32more.Windows.Win32.Foundation.BOOL, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Clean(self, bForce: win32more.Windows.Win32.Foundation.BOOL, bForceOEM: win32more.Windows.Win32.Foundation.BOOL, bFullClean: win32more.Windows.Win32.Foundation.BOOL, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAdvancedDisk2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9723f420-9355-42de-ab66-e31bb15beeac}')
    @commethod(3)
    def ChangePartitionType(self, ullOffset: UInt64, bForce: win32more.Windows.Win32.Foundation.BOOL, para: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.CHANGE_PARTITION_TYPE_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAdvancedDisk3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3858c0d5-0f35-4bf5-9714-69874963bc36}')
    @commethod(3)
    def GetProperties(self, pAdvDiskProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ADVANCEDDISK_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUniqueId(self, ppwszId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAdviseSink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8326cd1d-cf59-4936-b786-5efc08798e25}')
    @commethod(3)
    def OnNotify(self, lNumberOfNotifications: Int32, pNotificationArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsAsync(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d5d23b6d-5a55-4492-9889-397a3c2d2dbc}')
    @commethod(3)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Wait(self, pHrResult: POINTER(win32more.Windows.Win32.Foundation.HRESULT), pAsyncOut: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryStatus(self, pHrResult: POINTER(win32more.Windows.Win32.Foundation.HRESULT), pulPercentCompleted: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsController(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cb53d96e-dffb-474a-a078-790d1e2bc082}')
    @commethod(3)
    def GetProperties(self, pControllerProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubSystem(self, ppSubSystem: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsSubSystem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPortProperties(self, sPortNumber: Int16, pPortProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FlushCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def InvalidateCache(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def QueryAssociatedLuns(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsControllerControllerPort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ca5d735f-6bae-42c0-b30e-f2666045ce71}')
    @commethod(3)
    def QueryControllerPorts(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsControllerPort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{18691d0d-4e7f-43e8-92e4-cf44beeed11c}')
    @commethod(3)
    def GetProperties(self, pPortProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetController(self, ppController: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsController)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryAssociatedLuns(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsCreatePartitionEx(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9882f547-cfc3-420b-9750-00dfbec50662}')
    @commethod(3)
    def CreatePartitionEx(self, ullOffset: UInt64, ullSize: UInt64, ulAlign: UInt32, para: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.CREATE_PARTITION_PARAMETERS), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{07e5c822-f00c-47a1-8fce-b244da56fd06}')
    @commethod(3)
    def GetProperties(self, pDiskProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPack(self, ppPack: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsPack)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetIdentificationData(self, pLunInfo: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_INFORMATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryExtents(self, ppExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT)), plNumberOfExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ConvertStyle(self, NewStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def ClearFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDisk2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{40f73c8b-687d-4a13-8d96-3d7f2e683936}')
    @commethod(3)
    def SetSANMode(self, bEnable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDisk3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8f4b2f5d-ec15-4357-992f-473ef10975b9}')
    @commethod(3)
    def GetProperties2(self, pDiskProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_PROP2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryFreeExtents(self, ulAlign: UInt32, ppFreeExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FREE_EXTENT)), plNumberOfFreeExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDiskOnline(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{90681b1d-6a7f-48e8-9061-31b7aa125322}')
    @commethod(3)
    def Online(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Offline(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDiskPartitionMF(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{538684e0-ba3d-4bc0-aca9-164aff85c2a9}')
    @commethod(3)
    def GetPartitionFileSystemProperties(self, ullOffset: UInt64, pFileSystemProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPartitionFileSystemTypeName(self, ullOffset: UInt64, ppwszFileSystemTypeName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryPartitionFileSystemFormatSupport(self, ullOffset: UInt64, ppFileSystemSupportProps: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FORMAT_SUPPORT_PROP)), plNumberOfFileSystems: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FormatPartitionEx(self, ullOffset: UInt64, pwszFileSystemTypeName: win32more.Windows.Win32.Foundation.PWSTR, usFileSystemRevision: UInt16, ulDesiredUnitAllocationSize: UInt32, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, bForce: win32more.Windows.Win32.Foundation.BOOL, bQuickFormat: win32more.Windows.Win32.Foundation.BOOL, bEnableCompression: win32more.Windows.Win32.Foundation.BOOL, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDiskPartitionMF2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9cbe50ca-f2d2-4bf4-ace1-96896b729625}')
    @commethod(3)
    def FormatPartitionEx2(self, ullOffset: UInt64, pwszFileSystemTypeName: win32more.Windows.Win32.Foundation.PWSTR, usFileSystemRevision: UInt16, ulDesiredUnitAllocationSize: UInt32, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, Options: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDrive(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ff24efa4-aade-4b6b-898b-eaa6a20887c7}')
    @commethod(3)
    def GetProperties(self, pDriveProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubSystem(self, ppSubSystem: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsSubSystem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryExtents(self, ppExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_EXTENT)), plNumberOfExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ClearFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsDrive2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{60b5a730-addf-4436-8ca7-5769e2d1ffa4}')
    @commethod(3)
    def GetProperties2(self, pDriveProp2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_PROP2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHbaPort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{2abd757f-2851-4997-9a13-47d2a885d6ca}')
    @commethod(3)
    def GetProperties(self, pHbaPortProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetAllPathStatuses(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d99bdaae-b13a-4178-9fdb-e27f16b4603e}')
    @commethod(3)
    def QuerySubSystems(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Reenumerate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProviderPrivate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{98f17bf3-9f33-4f12-8714-8b4075092c2e}')
    @commethod(3)
    def QueryIfCreatedLun(self, pwszDevicePath: win32more.Windows.Win32.Foundation.PWSTR, pVdsLunInformation: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_INFORMATION), pLunId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProviderPrivateMpio(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{310a7715-ac2b-4c6f-9827-3d742f351676}')
    @commethod(3)
    def SetAllPathStatusesFromHbaPort(self, hbaPortProp: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_PROP, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProviderStoragePools(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d5b5937a-f188-4c79-b86c-11c920ad11b8}')
    @commethod(3)
    def QueryStoragePools(self, ulFlags: UInt32, ullRemainingFreeSpace: UInt64, pPoolAttributes: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_POOL_ATTRIBUTES), ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateLunInStoragePool(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, ullSizeInBytes: UInt64, StoragePoolId: Guid, pwszUnmaskingList: win32more.Windows.Win32.Foundation.PWSTR, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryMaxLunCreateSizeInStoragePool(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, StoragePoolId: Guid, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2), pullMaxLunSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProviderType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3e0f5166-542d-4fc6-947a-012174240b7e}')
    @commethod(3)
    def GetProviderType(self, pType: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsHwProviderType2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8190236f-c4d0-4e81-8011-d69512fcc984}')
    @commethod(3)
    def GetProviderType2(self, pType: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiInitiatorAdapter(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b07fedd4-1682-4440-9189-a39b55194dc5}')
    @commethod(3)
    def GetProperties(self, pInitiatorAdapterProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_INITIATOR_ADAPTER_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryInitiatorPortals(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def LoginToTarget(self, loginType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_TYPE, targetId: Guid, targetPortalId: Guid, initiatorPortalId: Guid, ulLoginFlags: UInt32, bHeaderDigest: win32more.Windows.Win32.Foundation.BOOL, bDataDigest: win32more.Windows.Win32.Foundation.BOOL, authType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_AUTH_TYPE, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def LogoutFromTarget(self, targetId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiInitiatorPortal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{38a0a9ab-7cc8-4693-ac07-1f28bd03c3da}')
    @commethod(3)
    def GetProperties(self, pInitiatorPortalProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_INITIATOR_PORTAL_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetInitiatorAdapter(self, ppInitiatorAdapter: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsIscsiInitiatorAdapter)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetIpsecTunnelAddress(self, pTunnelAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS), pDestinationAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetIpsecSecurity(self, targetPortalId: Guid, pullSecurityFlags: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetIpsecSecurity(self, targetPortalId: Guid, ullSecurityFlags: UInt64, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiPortal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7fa1499d-ec85-4a8a-a47b-ff69201fcd34}')
    @commethod(3)
    def GetProperties(self, pPortalProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubSystem(self, ppSubSystem: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsSubSystem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryAssociatedPortalGroups(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetIpsecTunnelAddress(self, pTunnelAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS), pDestinationAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetIpsecSecurity(self, pInitiatorPortalAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS), pullSecurityFlags: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetIpsecSecurity(self, pInitiatorPortalAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS), ullSecurityFlags: UInt64, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiPortalGroup(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fef5f89d-a3dd-4b36-bf28-e7dde045c593}')
    @commethod(3)
    def GetProperties(self, pPortalGroupProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTALGROUP_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetTarget(self, ppTarget: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsIscsiTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryAssociatedPortals(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddPortal(self, portalId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemovePortal(self, portalId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Delete(self, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiPortalLocal(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ad837c28-52c1-421d-bf04-fae7da665396}')
    @commethod(3)
    def SetIpsecSecurityLocal(self, ullSecurityFlags: UInt64, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsIscsiTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{aa8f5055-83e5-4bcc-aa73-19851a36a849}')
    @commethod(3)
    def GetProperties(self, pTargetProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_TARGET_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubSystem(self, ppSubSystem: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsSubSystem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryPortalGroups(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryAssociatedLuns(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreatePortalGroup(self, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Delete(self, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetFriendlyName(self, pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetSharedSecret(self, pTargetSharedSecret: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_SHARED_SECRET), pwszInitiatorName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RememberInitiatorSharedSecret(self, pwszInitiatorName: win32more.Windows.Win32.Foundation.PWSTR, pInitiatorSharedSecret: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_SHARED_SECRET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetConnectedInitiators(self, pppwszInitiatorList: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), plNumberOfInitiators: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLun(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3540a9c7-e60f-4111-a840-8bba6c2c83d8}')
    @commethod(3)
    def GetProperties(self, pLunProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSubSystem(self, ppSubSystem: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsSubSystem)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetIdentificationData(self, pLunInfo: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_INFORMATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryActiveControllers(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Extend(self, ullNumberOfBytesToAdd: UInt64, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Shrink(self, ullNumberOfBytesToRemove: UInt64, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def QueryPlexes(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def AddPlex(self, lunId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RemovePlex(self, plexId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Recover(self, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetMask(self, pwszUnmaskingList: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Delete(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def AssociateControllers(self, pActiveControllerIdArray: POINTER(Guid), lNumberOfActiveControllers: Int32, pInactiveControllerIdArray: POINTER(Guid), lNumberOfInactiveControllers: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def QueryHints(self, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def ApplyHints(self, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def QueryMaxLunExtendSize(self, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, pullMaxBytesToBeAdded: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLun2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e5b3a735-9efb-499a-8071-4394d9ee6fcb}')
    @commethod(3)
    def QueryHints2(self, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ApplyHints2(self, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunControllerPorts(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{451fe266-da6d-406a-bb60-82e534f85aeb}')
    @commethod(3)
    def AssociateControllerPorts(self, pActiveControllerPortIdArray: POINTER(Guid), lNumberOfActiveControllerPorts: Int32, pInactiveControllerPortIdArray: POINTER(Guid), lNumberOfInactiveControllerPorts: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryActiveControllerPorts(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunIscsi(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0d7c1e64-b59b-45ae-b86a-2c2cc6a42067}')
    @commethod(3)
    def AssociateTargets(self, pTargetIdArray: POINTER(Guid), lNumberOfTargets: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryAssociatedTargets(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunMpio(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7c5fbae3-333a-48a1-a982-33c15788cde3}')
    @commethod(3)
    def GetPathInfo(self, ppPaths: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_INFO)), plNumberOfPaths: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLoadBalancePolicy(self, pPolicy: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM), ppPaths: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_POLICY)), plNumberOfPaths: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetLoadBalancePolicy(self, policy: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM, pPaths: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_POLICY), lNumberOfPaths: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSupportedLbPolicies(self, pulLbFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunNaming(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{907504cb-6b4e-4d88-a34d-17ba661fbb06}')
    @commethod(3)
    def SetFriendlyName(self, pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunNumber(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d3f95e46-54b3-41f9-b678-0f1871443a08}')
    @commethod(3)
    def GetLunNumber(self, pulLunNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsLunPlex(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0ee1a790-5d2e-4abb-8c99-c481e8be2138}')
    @commethod(3)
    def GetProperties(self, pPlexProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLun(self, ppLun: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsLun)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryExtents(self, ppExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_EXTENT)), plNumberOfExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryHints(self, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ApplyHints(self, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsMaintenance(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{daebeef3-8523-47ed-a2b9-05cecce2a1ae}')
    @commethod(3)
    def StartMaintenance(self, operation: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def StopMaintenance(self, operation: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def PulseMaintenance(self, operation: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION, ulCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsOpenVDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{75c8f324-f715-4fe3-a28e-f9011b61a4a1}')
    @commethod(3)
    def Attach(self, pStringSecurityDescriptor: win32more.Windows.Win32.Foundation.PWSTR, Flags: win32more.Windows.Win32.Storage.Vhd.ATTACH_VIRTUAL_DISK_FLAG, ProviderSpecificFlags: UInt32, TimeoutInMs: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Detach(self, Flags: win32more.Windows.Win32.Storage.Vhd.DETACH_VIRTUAL_DISK_FLAG, ProviderSpecificFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DetachAndDelete(self, Flags: win32more.Windows.Win32.Storage.Vhd.DETACH_VIRTUAL_DISK_FLAG, ProviderSpecificFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Compact(self, Flags: win32more.Windows.Win32.Storage.Vhd.COMPACT_VIRTUAL_DISK_FLAG, Reserved: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Merge(self, Flags: win32more.Windows.Win32.Storage.Vhd.MERGE_VIRTUAL_DISK_FLAG, MergeDepth: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Expand(self, Flags: win32more.Windows.Win32.Storage.Vhd.EXPAND_VIRTUAL_DISK_FLAG, NewSize: UInt64, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsPack(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3b69d7f5-9d94-4648-91ca-79939ba263bf}')
    @commethod(3)
    def GetProperties(self, pPackProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProvider(self, ppProvider: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryVolumes(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryDisks(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateVolume(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE, pInputDiskArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INPUT_DISK), lNumberOfDisks: Int32, ulStripeSize: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AddDisk(self, DiskId: Guid, PartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE, bAsHotSpare: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def MigrateDisks(self, pDiskArray: POINTER(Guid), lNumberOfDisks: Int32, TargetPack: Guid, bForce: win32more.Windows.Win32.Foundation.BOOL, bQueryOnly: win32more.Windows.Win32.Foundation.BOOL, pResults: POINTER(win32more.Windows.Win32.Foundation.HRESULT), pbRebootNeeded: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReplaceDisk(self, OldDiskId: Guid, NewDiskId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def RemoveMissingDisk(self, DiskId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Recover(self, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsPack2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{13b50bff-290a-47dd-8558-b7c58db1a71a}')
    @commethod(3)
    def CreateVolume2(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE, pInputDiskArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INPUT_DISK), lNumberOfDisks: Int32, ulStripeSize: UInt32, ulAlign: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{10c5e575-7984-4e81-a56b-431f5f92ae42}')
    @commethod(3)
    def GetProperties(self, pProviderProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsProviderPrivate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{11f3cd41-b7e8-48ff-9472-9dff018aa292}')
    @commethod(3)
    def GetObject(self, ObjectId: Guid, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE, ppObjectUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnLoad(self, pwszMachineName: win32more.Windows.Win32.Foundation.PWSTR, pCallbackObject: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnUnload(self, bForceUnload: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsProviderSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1732be13-e8f9-4a03-bfbc-5f616aa66ce1}')
    @commethod(3)
    def GetVersionSupport(self, ulVersionSupport: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsRemovable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0316560b-5db4-4ed9-bbb5-213436ddc0d9}')
    @commethod(3)
    def QueryMedia(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Eject(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0818a8ef-9ba9-40d8-a6f9-e22833cc771e}')
    @commethod(3)
    def IsServiceReady(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def WaitForServiceReady(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetProperties(self, pServiceProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryProviders(self, masks: UInt32, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def QueryMaskedDisks(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def QueryUnallocatedDisks(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetObject(self, ObjectId: Guid, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE, ppObjectUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def QueryDriveLetters(self, wcFirstLetter: Char, count: UInt32, pDriveLetterPropArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_LETTER_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def QueryFileSystemTypes(self, ppFileSystemTypeProps: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE_PROP)), plNumberOfFileSystems: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Reenumerate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CleanupObsoleteMountPoints(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Advise(self, pSink: win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAdviseSink, pdwCookie: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Unadvise(self, dwCookie: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Reboot(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def SetFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def ClearFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceHba(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0ac13689-3134-47c6-a17c-4669216801be}')
    @commethod(3)
    def QueryHbaPorts(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceInitialization(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4afc3636-db01-4052-80c3-03bbcb8d3c69}')
    @commethod(3)
    def Initialize(self, pwszMachineName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceIscsi(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{14fbe036-3ed7-4e10-90e9-a5ff991aff01}')
    @commethod(3)
    def GetInitiatorName(self, ppwszIscsiName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryInitiatorAdapters(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetIpsecGroupPresharedKey(self, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetAllIpsecTunnelAddresses(self, pTunnelAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS), pDestinationAddress: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetAllIpsecSecurity(self, targetPortalId: Guid, ullSecurityFlags: UInt64, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetInitiatorSharedSecret(self, pInitiatorSharedSecret: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_SHARED_SECRET), targetId: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RememberTargetSharedSecret(self, targetId: Guid, pTargetSharedSecret: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_SHARED_SECRET)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceLoader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e0393303-90d4-4a97-ab71-e9b671ee2729}')
    @commethod(3)
    def LoadService(self, pwszMachineName: win32more.Windows.Win32.Foundation.PWSTR, ppService: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsService)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceSAN(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fc5d23e8-a88b-41a5-8de0-2d2f73c5a630}')
    @commethod(3)
    def GetSANPolicy(self, pSanPolicy: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSANPolicy(self, SanPolicy: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceSw(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{15fc031c-0652-4306-b2c3-f558b8f837e2}')
    @commethod(3)
    def GetDiskObject(self, pwszDeviceID: win32more.Windows.Win32.Foundation.PWSTR, ppDiskUnk: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsServiceUninstallDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b6b22da8-f903-4be7-b492-c09d875ac9da}')
    @commethod(3)
    def GetDiskIdFromLunInfo(self, pLunInfo: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_INFORMATION), pDiskId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UninstallDisks(self, pDiskIdArray: POINTER(Guid), ulCount: UInt32, bForce: win32more.Windows.Win32.Foundation.BOOLEAN, pbReboot: POINTER(Byte), pResults: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsStoragePool(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{932ca8cf-0eb3-4ba8-9620-22665d7f8450}')
    @commethod(3)
    def GetProvider(self, ppProvider: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperties(self, pStoragePoolProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAttributes(self, pStoragePoolAttributes: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_POOL_ATTRIBUTES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryDriveExtents(self, ppExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_DRIVE_EXTENT)), plNumberOfExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def QueryAllocatedLuns(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def QueryAllocatedStoragePools(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6fcee2d3-6d90-4f91-80e2-a5c7caaca9d8}')
    @commethod(3)
    def GetProperties(self, pSubSystemProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProvider(self, ppProvider: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsProvider)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryControllers(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryLuns(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def QueryDrives(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDrive(self, sBusNumber: Int16, sSlotNumber: Int16, ppDrive: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsDrive)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Reenumerate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetControllerStatus(self, pOnlineControllerIdArray: POINTER(Guid), lNumberOfOnlineControllers: Int32, pOfflineControllerIdArray: POINTER(Guid), lNumberOfOfflineControllers: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CreateLun(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, ullSizeInBytes: UInt64, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, pwszUnmaskingList: win32more.Windows.Win32.Foundation.PWSTR, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ReplaceDrive(self, DriveToBeReplaced: Guid, ReplacementDrive: Guid) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetStatus(self, status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def QueryMaxLunCreateSize(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, pHints: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS), pullMaxLunSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystem2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{be666735-7800-4a77-9d9c-40f85b87e292}')
    @commethod(3)
    def GetProperties2(self, pSubSystemProp2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_PROP2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDrive2(self, sBusNumber: Int16, sSlotNumber: Int16, ulEnclosureNumber: UInt32, ppDrive: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsDrive)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateLun2(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, ullSizeInBytes: UInt64, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, pwszUnmaskingList: win32more.Windows.Win32.Foundation.PWSTR, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryMaxLunCreateSize2(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE, pDriveIdArray: POINTER(Guid), lNumberOfDrives: Int32, pHints2: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HINTS2), pullMaxLunSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystemImportTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{83bfb87f-43fb-4903-baa6-127f01029eec}')
    @commethod(3)
    def GetImportTarget(self, ppwszIscsiName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetImportTarget(self, pwszIscsiName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystemInterconnect(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9e6fa560-c141-477b-83ba-0b6c38f7febf}')
    @commethod(3)
    def GetSupportedInterconnects(self, pulSupportedInterconnectsFlag: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystemIscsi(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0027346f-40d0-4b45-8cec-5906dc0380c8}')
    @commethod(3)
    def QueryTargets(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryPortals(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateTarget(self, pwszIscsiName: win32more.Windows.Win32.Foundation.PWSTR, pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetIpsecGroupPresharedKey(self, pIpsecKey: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_KEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSubSystemNaming(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0d70faa3-9cd4-4900-aa20-6981b6aafc75}')
    @commethod(3)
    def SetFriendlyName(self, pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsSwProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9aa58360-ce33-4f92-b658-ed24b14425b8}')
    @commethod(3)
    def QueryPacks(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreatePack(self, ppPack: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsPack)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVDisk(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1e062b84-e5e6-4b4b-8a25-67b81e8f13e8}')
    @commethod(3)
    def Open(self, AccessMask: win32more.Windows.Win32.Storage.Vhd.VIRTUAL_DISK_ACCESS_MASK, Flags: win32more.Windows.Win32.Storage.Vhd.OPEN_VIRTUAL_DISK_FLAG, ReadWriteDepth: UInt32, ppOpenVDisk: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsOpenVDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetProperties(self, pDiskProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_PROPERTIES)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetHostVolume(self, ppVolume: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsVolume)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDeviceName(self, ppDeviceName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVdProvider(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b481498c-8354-45f9-84a0-0bdd2832a91f}')
    @commethod(3)
    def QueryVDisks(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateVDisk(self, VirtualDeviceType: POINTER(win32more.Windows.Win32.Storage.Vhd.VIRTUAL_STORAGE_TYPE), pPath: win32more.Windows.Win32.Foundation.PWSTR, pStringSecurityDescriptor: win32more.Windows.Win32.Foundation.PWSTR, Flags: win32more.Windows.Win32.Storage.Vhd.CREATE_VIRTUAL_DISK_FLAG, ProviderSpecificFlags: UInt32, Reserved: UInt32, pCreateDiskParameters: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CREATE_VDISK_PARAMETERS), ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddVDisk(self, VirtualDeviceType: POINTER(win32more.Windows.Win32.Storage.Vhd.VIRTUAL_STORAGE_TYPE), pPath: win32more.Windows.Win32.Foundation.PWSTR, ppVDisk: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsVDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDiskFromVDisk(self, pVDisk: win32more.Windows.Win32.Storage.VirtualDiskService.IVdsVDisk, ppDisk: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetVDiskFromDisk(self, pDisk: win32more.Windows.Win32.Storage.VirtualDiskService.IVdsDisk, ppVDisk: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsVDisk)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolume(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{88306bb2-e71f-478c-86a2-79da200a0f11}')
    @commethod(3)
    def GetProperties(self, pVolumeProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPack(self, ppPack: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsPack)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryPlexes(self, ppEnum: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IEnumVdsObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Extend(self, pInputDiskArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INPUT_DISK), lNumberOfDisks: Int32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Shrink(self, ullNumberOfBytesToRemove: UInt64, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AddPlex(self, VolumeId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def BreakPlex(self, plexId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RemovePlex(self, plexId: Guid, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def Delete(self, bForce: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetFlags(self, ulFlags: UInt32, bRevertOnClose: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def ClearFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolume2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{72ae6713-dcbb-4a03-b36b-371f6ac6b53d}')
    @commethod(3)
    def GetProperties2(self, pVolumeProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PROP2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumeMF(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ee2d5ded-6236-4169-931d-b9778ce03dc6}')
    @commethod(3)
    def GetFileSystemProperties(self, pFileSystemProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Format(self, type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, dwUnitAllocationSize: UInt32, bForce: win32more.Windows.Win32.Foundation.BOOL, bQuickFormat: win32more.Windows.Win32.Foundation.BOOL, bEnableCompression: win32more.Windows.Win32.Foundation.BOOL, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddAccessPath(self, pwszPath: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def QueryAccessPaths(self, pwszPathArray: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), plNumberOfAccessPaths: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def QueryReparsePoints(self, ppReparsePointProps: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_REPARSE_POINT_PROP)), plNumberOfReparsePointProps: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteAccessPath(self, pwszPath: win32more.Windows.Win32.Foundation.PWSTR, bForce: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Mount(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def Dismount(self, bForce: win32more.Windows.Win32.Foundation.BOOL, bPermanent: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetFileSystemFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def ClearFileSystemFlags(self, ulFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumeMF2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4dbcee9a-6343-4651-b85f-5e75d74d983c}')
    @commethod(3)
    def GetFileSystemTypeName(self, ppwszFileSystemTypeName: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def QueryFileSystemFormatSupport(self, ppFileSystemSupportProps: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FORMAT_SUPPORT_PROP)), plNumberOfFileSystems: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def FormatEx(self, pwszFileSystemTypeName: win32more.Windows.Win32.Foundation.PWSTR, usFileSystemRevision: UInt16, ulDesiredUnitAllocationSize: UInt32, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, bForce: win32more.Windows.Win32.Foundation.BOOL, bQuickFormat: win32more.Windows.Win32.Foundation.BOOL, bEnableCompression: win32more.Windows.Win32.Foundation.BOOL, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumeMF3(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6788faf9-214e-4b85-ba59-266953616e09}')
    @commethod(3)
    def QueryVolumeGuidPathnames(self, pwszPathArray: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), pulNumberOfPaths: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def FormatEx2(self, pwszFileSystemTypeName: win32more.Windows.Win32.Foundation.PWSTR, usFileSystemRevision: UInt16, ulDesiredUnitAllocationSize: UInt32, pwszLabel: win32more.Windows.Win32.Foundation.PWSTR, Options: UInt32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OfflineVolume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumeOnline(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1be2275a-b315-4f70-9e44-879b3a2a53f2}')
    @commethod(3)
    def Online(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumePlex(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4daa0135-e1d1-40f1-aaa5-3cc1e53221c3}')
    @commethod(3)
    def GetProperties(self, pPlexProperties: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_PROP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetVolume(self, ppVolume: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsVolume)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def QueryExtents(self, ppExtentArray: POINTER(POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT)), plNumberOfExtents: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Repair(self, pInputDiskArray: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INPUT_DISK), lNumberOfDisks: Int32, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IVdsVolumeShrink(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d68168c9-82a2-4f85-b6e9-74707c49a58f}')
    @commethod(3)
    def QueryMaxReclaimableBytes(self, pullMaxNumberOfReclaimableBytes: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Shrink(self, ullDesiredNumberOfReclaimableBytes: UInt64, ullMinNumberOfReclaimableBytes: UInt64, ppAsync: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.IVdsAsync)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class VDS_ADVANCEDDISK_PROP(Structure):
    pwszId: win32more.Windows.Win32.Foundation.PWSTR
    pwszPathname: win32more.Windows.Win32.Foundation.PWSTR
    pwszLocation: win32more.Windows.Win32.Foundation.PWSTR
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pswzIdentifier: win32more.Windows.Win32.Foundation.PWSTR
    usIdentifierFormat: UInt16
    ulNumber: UInt32
    pwszSerialNumber: win32more.Windows.Win32.Foundation.PWSTR
    pwszFirmwareVersion: win32more.Windows.Win32.Foundation.PWSTR
    pwszManufacturer: win32more.Windows.Win32.Foundation.PWSTR
    pwszModel: win32more.Windows.Win32.Foundation.PWSTR
    ullTotalSize: UInt64
    ullAllocatedSize: UInt64
    ulLogicalSectorSize: UInt32
    ulPhysicalSectorSize: UInt32
    ulPartitionCount: UInt32
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    BusType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    PartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    ulFlags: UInt32
    dwDeviceType: UInt32
    class _Anonymous_e__Union(Union):
        dwSignature: UInt32
        DiskGuid: Guid
class VDS_ASYNC_OUTPUT(Structure):
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        cp: _cp
        cv: _cv
        bvp: _bvp
        sv: _sv
        cl: _cl
        ct: _ct
        cpg: _cpg
        cvd: _cvd
        class _cp(Structure):
            ullOffset: UInt64
            volumeId: Guid
        class _cv(Structure):
            pVolumeUnk: win32more.Windows.Win32.System.Com.IUnknown
        class _bvp(Structure):
            pVolumeUnk: win32more.Windows.Win32.System.Com.IUnknown
        class _sv(Structure):
            ullReclaimedBytes: UInt64
        class _cl(Structure):
            pLunUnk: win32more.Windows.Win32.System.Com.IUnknown
        class _ct(Structure):
            pTargetUnk: win32more.Windows.Win32.System.Com.IUnknown
        class _cpg(Structure):
            pPortalGroupUnk: win32more.Windows.Win32.System.Com.IUnknown
        class _cvd(Structure):
            pVDiskUnk: win32more.Windows.Win32.System.Com.IUnknown
VDS_ASYNC_OUTPUT_TYPE = Int32
VDS_ASYNCOUT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 0
VDS_ASYNCOUT_CREATEVOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 1
VDS_ASYNCOUT_EXTENDVOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 2
VDS_ASYNCOUT_SHRINKVOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 3
VDS_ASYNCOUT_ADDVOLUMEPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 4
VDS_ASYNCOUT_BREAKVOLUMEPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 5
VDS_ASYNCOUT_REMOVEVOLUMEPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 6
VDS_ASYNCOUT_REPAIRVOLUMEPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 7
VDS_ASYNCOUT_RECOVERPACK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 8
VDS_ASYNCOUT_REPLACEDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 9
VDS_ASYNCOUT_CREATEPARTITION: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 10
VDS_ASYNCOUT_CLEAN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 11
VDS_ASYNCOUT_CREATELUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 50
VDS_ASYNCOUT_ADDLUNPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 52
VDS_ASYNCOUT_REMOVELUNPLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 53
VDS_ASYNCOUT_EXTENDLUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 54
VDS_ASYNCOUT_SHRINKLUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 55
VDS_ASYNCOUT_RECOVERLUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 56
VDS_ASYNCOUT_LOGINTOTARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 60
VDS_ASYNCOUT_LOGOUTFROMTARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 61
VDS_ASYNCOUT_CREATETARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 62
VDS_ASYNCOUT_CREATEPORTALGROUP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 63
VDS_ASYNCOUT_DELETETARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 64
VDS_ASYNCOUT_ADDPORTAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 65
VDS_ASYNCOUT_REMOVEPORTAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 66
VDS_ASYNCOUT_DELETEPORTALGROUP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 67
VDS_ASYNCOUT_FORMAT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 101
VDS_ASYNCOUT_CREATE_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 200
VDS_ASYNCOUT_ATTACH_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 201
VDS_ASYNCOUT_COMPACT_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 202
VDS_ASYNCOUT_MERGE_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 203
VDS_ASYNCOUT_EXPAND_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ASYNC_OUTPUT_TYPE = 204
class VDS_CONTROLLER_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_CONTROLLER
    controllerId: Guid
class VDS_CONTROLLER_PROP(Structure):
    id: Guid
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    sNumberOfPorts: Int16
VDS_CONTROLLER_STATUS = Int32
VDS_CS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 0
VDS_CS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 1
VDS_CS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 2
VDS_CS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 4
VDS_CS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 5
VDS_CS_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_STATUS = 8
class VDS_CREATE_VDISK_PARAMETERS(Structure):
    UniqueId: Guid
    MaximumSize: UInt64
    BlockSizeInBytes: UInt32
    SectorSizeInBytes: UInt32
    pParentPath: win32more.Windows.Win32.Foundation.PWSTR
    pSourcePath: win32more.Windows.Win32.Foundation.PWSTR
class VDS_DISK_EXTENT(Structure):
    diskId: Guid
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE
    ullOffset: UInt64
    ullSize: UInt64
    volumeId: Guid
    plexId: Guid
    memberIdx: UInt32
VDS_DISK_EXTENT_TYPE = Int32
VDS_DET_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 0
VDS_DET_FREE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 1
VDS_DET_DATA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 2
VDS_DET_OEM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 3
VDS_DET_ESP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 4
VDS_DET_MSR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 5
VDS_DET_LDM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 6
VDS_DET_CLUSTER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 7
VDS_DET_UNUSABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_EXTENT_TYPE = 32767
VDS_DISK_FLAG = Int32
VDS_DF_AUDIO_CD: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 1
VDS_DF_HOTSPARE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 2
VDS_DF_RESERVE_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 4
VDS_DF_MASKED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 8
VDS_DF_STYLE_CONVERTIBLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 16
VDS_DF_CLUSTERED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 32
VDS_DF_READ_ONLY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 64
VDS_DF_SYSTEM_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 128
VDS_DF_BOOT_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 256
VDS_DF_PAGEFILE_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 512
VDS_DF_HIBERNATIONFILE_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 1024
VDS_DF_CRASHDUMP_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 2048
VDS_DF_HAS_ARC_PATH: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 4096
VDS_DF_DYNAMIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 8192
VDS_DF_BOOT_FROM_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 16384
VDS_DF_CURRENT_READ_ONLY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 32768
VDS_DF_REFS_NOT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_FLAG = 65536
class VDS_DISK_FREE_EXTENT(Structure):
    diskId: Guid
    ullOffset: UInt64
    ullSize: UInt64
class VDS_DISK_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DISK
    diskId: Guid
VDS_DISK_OFFLINE_REASON = Int32
VDSDiskOfflineReasonNone: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 0
VDSDiskOfflineReasonPolicy: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 1
VDSDiskOfflineReasonRedundantPath: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 2
VDSDiskOfflineReasonSnapshot: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 3
VDSDiskOfflineReasonCollision: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 4
VDSDiskOfflineReasonResourceExhaustion: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 5
VDSDiskOfflineReasonWriteFailure: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 6
VDSDiskOfflineReasonDIScan: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 7
VDSDiskOfflineReasonLostDataPersistence: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON = 8
class VDS_DISK_PROP(Structure):
    id: Guid
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS
    ReserveMode: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    dwDeviceType: UInt32
    dwMediaType: UInt32
    ullSize: UInt64
    ulBytesPerSector: UInt32
    ulSectorsPerTrack: UInt32
    ulTracksPerCylinder: UInt32
    ulFlags: UInt32
    BusType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    PartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    pwszDiskAddress: win32more.Windows.Win32.Foundation.PWSTR
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszAdaptorName: win32more.Windows.Win32.Foundation.PWSTR
    pwszDevicePath: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous_e__Union(Union):
        dwSignature: UInt32
        DiskGuid: Guid
class VDS_DISK_PROP2(Structure):
    id: Guid
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS
    OfflineReason: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_OFFLINE_REASON
    ReserveMode: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    dwDeviceType: UInt32
    dwMediaType: UInt32
    ullSize: UInt64
    ulBytesPerSector: UInt32
    ulSectorsPerTrack: UInt32
    ulTracksPerCylinder: UInt32
    ulFlags: UInt32
    BusType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    PartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    Anonymous: _Anonymous_e__Union
    pwszDiskAddress: win32more.Windows.Win32.Foundation.PWSTR
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszAdaptorName: win32more.Windows.Win32.Foundation.PWSTR
    pwszDevicePath: win32more.Windows.Win32.Foundation.PWSTR
    pwszLocationPath: win32more.Windows.Win32.Foundation.PWSTR
    class _Anonymous_e__Union(Union):
        dwSignature: UInt32
        DiskGuid: Guid
VDS_DISK_STATUS = Int32
VDS_DS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 0
VDS_DS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 1
VDS_DS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 2
VDS_DS_NO_MEDIA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 3
VDS_DS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 5
VDS_DS_MISSING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 6
VDS_DS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_STATUS = 4
class VDS_DRIVE_EXTENT(Structure):
    id: Guid
    LunId: Guid
    ullSize: UInt64
    bUsed: win32more.Windows.Win32.Foundation.BOOL
VDS_DRIVE_FLAG = Int32
VDS_DRF_HOTSPARE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_FLAG = 1
VDS_DRF_ASSIGNED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_FLAG = 2
VDS_DRF_UNASSIGNED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_FLAG = 4
VDS_DRF_HOTSPARE_IN_USE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_FLAG = 8
VDS_DRF_HOTSPARE_STANDBY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_FLAG = 16
VDS_DRIVE_LETTER_FLAG = Int32
VDS_DLF_NON_PERSISTENT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_LETTER_FLAG = 1
class VDS_DRIVE_LETTER_NOTIFICATION(Structure):
    ulEvent: UInt32
    wcLetter: Char
    volumeId: Guid
class VDS_DRIVE_LETTER_PROP(Structure):
    wcLetter: Char
    volumeId: Guid
    ulFlags: UInt32
    bUsed: win32more.Windows.Win32.Foundation.BOOL
class VDS_DRIVE_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DRIVE
    driveId: Guid
class VDS_DRIVE_PROP(Structure):
    id: Guid
    ullSize: UInt64
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    sInternalBusNumber: Int16
    sSlotNumber: Int16
class VDS_DRIVE_PROP2(Structure):
    id: Guid
    ullSize: UInt64
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    sInternalBusNumber: Int16
    sSlotNumber: Int16
    ulEnclosureNumber: UInt32
    busType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    ulSpindleSpeed: UInt32
VDS_DRIVE_STATUS = Int32
VDS_DRS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 0
VDS_DRS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 1
VDS_DRS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 2
VDS_DRS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 4
VDS_DRS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 5
VDS_DRS_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_STATUS = 8
VDS_FILE_SYSTEM_FLAG = Int32
VDS_FSF_SUPPORT_FORMAT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 1
VDS_FSF_SUPPORT_QUICK_FORMAT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 2
VDS_FSF_SUPPORT_COMPRESS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 4
VDS_FSF_SUPPORT_SPECIFY_LABEL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 8
VDS_FSF_SUPPORT_MOUNT_POINT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 16
VDS_FSF_SUPPORT_REMOVABLE_MEDIA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 32
VDS_FSF_SUPPORT_EXTEND: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 64
VDS_FSF_ALLOCATION_UNIT_512: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 65536
VDS_FSF_ALLOCATION_UNIT_1K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 131072
VDS_FSF_ALLOCATION_UNIT_2K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 262144
VDS_FSF_ALLOCATION_UNIT_4K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 524288
VDS_FSF_ALLOCATION_UNIT_8K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 1048576
VDS_FSF_ALLOCATION_UNIT_16K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 2097152
VDS_FSF_ALLOCATION_UNIT_32K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 4194304
VDS_FSF_ALLOCATION_UNIT_64K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 8388608
VDS_FSF_ALLOCATION_UNIT_128K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 16777216
VDS_FSF_ALLOCATION_UNIT_256K: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FLAG = 33554432
VDS_FILE_SYSTEM_FORMAT_SUPPORT_FLAG = Int32
VDS_FSS_DEFAULT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FORMAT_SUPPORT_FLAG = 1
VDS_FSS_PREVIOUS_REVISION: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FORMAT_SUPPORT_FLAG = 2
VDS_FSS_RECOMMENDED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_FORMAT_SUPPORT_FLAG = 4
class VDS_FILE_SYSTEM_FORMAT_SUPPORT_PROP(Structure):
    ulFlags: UInt32
    usRevision: UInt16
    ulDefaultUnitAllocationSize: UInt32
    rgulAllowedUnitAllocationSizes: UInt32 * 32
    wszName: Char * 32
class VDS_FILE_SYSTEM_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_FILE_SYSTEM
    volumeId: Guid
    dwPercentCompleted: UInt32
class VDS_FILE_SYSTEM_PROP(Structure):
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE
    volumeId: Guid
    ulFlags: UInt32
    ullTotalAllocationUnits: UInt64
    ullAvailableAllocationUnits: UInt64
    ulAllocationUnitSize: UInt32
    pwszLabel: win32more.Windows.Win32.Foundation.PWSTR
VDS_FILE_SYSTEM_PROP_FLAG = Int32
VDS_FPF_COMPRESSED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_PROP_FLAG = 1
VDS_FILE_SYSTEM_TYPE = Int32
VDS_FST_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 0
VDS_FST_RAW: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 1
VDS_FST_FAT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 2
VDS_FST_FAT32: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 3
VDS_FST_NTFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 4
VDS_FST_CDFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 5
VDS_FST_UDF: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 6
VDS_FST_EXFAT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 7
VDS_FST_CSVFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 8
VDS_FST_REFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE = 9
class VDS_FILE_SYSTEM_TYPE_PROP(Structure):
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE
    wszName: Char * 8
    ulFlags: UInt32
    ulCompressionFlags: UInt32
    ulMaxLableLength: UInt32
    pwszIllegalLabelCharSet: win32more.Windows.Win32.Foundation.PWSTR
VDS_FORMAT_OPTION_FLAGS = Int32
VDS_FSOF_NONE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FORMAT_OPTION_FLAGS = 0
VDS_FSOF_FORCE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FORMAT_OPTION_FLAGS = 1
VDS_FSOF_QUICK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FORMAT_OPTION_FLAGS = 2
VDS_FSOF_COMPRESSION: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FORMAT_OPTION_FLAGS = 4
VDS_FSOF_DUPLICATE_METADATA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FORMAT_OPTION_FLAGS = 8
class VDS_HBAPORT_PROP(Structure):
    id: Guid
    wwnNode: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_WWN
    wwnPort: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_WWN
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS
    ulPortSpeed: UInt32
    ulSupportedPortSpeed: UInt32
VDS_HBAPORT_SPEED_FLAG = Int32
VDS_HSF_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 0
VDS_HSF_1GBIT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 1
VDS_HSF_2GBIT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 2
VDS_HSF_10GBIT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 4
VDS_HSF_4GBIT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 8
VDS_HSF_NOT_NEGOTIATED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_SPEED_FLAG = 32768
VDS_HBAPORT_STATUS = Int32
VDS_HPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 1
VDS_HPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 2
VDS_HPS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 3
VDS_HPS_BYPASSED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 4
VDS_HPS_DIAGNOSTICS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 5
VDS_HPS_LINKDOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 6
VDS_HPS_ERROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 7
VDS_HPS_LOOPBACK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_STATUS = 8
VDS_HBAPORT_TYPE = Int32
VDS_HPT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 1
VDS_HPT_OTHER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 2
VDS_HPT_NOTPRESENT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 3
VDS_HPT_NPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 5
VDS_HPT_NLPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 6
VDS_HPT_FLPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 7
VDS_HPT_FPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 8
VDS_HPT_EPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 9
VDS_HPT_GPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 10
VDS_HPT_LPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 20
VDS_HPT_PTP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_TYPE = 21
VDS_HEALTH = Int32
VDS_H_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 0
VDS_H_HEALTHY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 1
VDS_H_REBUILDING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 2
VDS_H_STALE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 3
VDS_H_FAILING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 4
VDS_H_FAILING_REDUNDANCY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 5
VDS_H_FAILED_REDUNDANCY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 6
VDS_H_FAILED_REDUNDANCY_FAILING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 7
VDS_H_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 8
VDS_H_REPLACED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 9
VDS_H_PENDING_FAILURE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 10
VDS_H_DEGRADED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH = 11
class VDS_HINTS(Structure):
    ullHintMask: UInt64
    ullExpectedMaximumSize: UInt64
    ulOptimalReadSize: UInt32
    ulOptimalReadAlignment: UInt32
    ulOptimalWriteSize: UInt32
    ulOptimalWriteAlignment: UInt32
    ulMaximumDriveCount: UInt32
    ulStripeSize: UInt32
    bFastCrashRecoveryRequired: win32more.Windows.Win32.Foundation.BOOL
    bMostlyReads: win32more.Windows.Win32.Foundation.BOOL
    bOptimizeForSequentialReads: win32more.Windows.Win32.Foundation.BOOL
    bOptimizeForSequentialWrites: win32more.Windows.Win32.Foundation.BOOL
    bRemapEnabled: win32more.Windows.Win32.Foundation.BOOL
    bReadBackVerifyEnabled: win32more.Windows.Win32.Foundation.BOOL
    bWriteThroughCachingEnabled: win32more.Windows.Win32.Foundation.BOOL
    bHardwareChecksumEnabled: win32more.Windows.Win32.Foundation.BOOL
    bIsYankable: win32more.Windows.Win32.Foundation.BOOL
    sRebuildPriority: Int16
class VDS_HINTS2(Structure):
    ullHintMask: UInt64
    ullExpectedMaximumSize: UInt64
    ulOptimalReadSize: UInt32
    ulOptimalReadAlignment: UInt32
    ulOptimalWriteSize: UInt32
    ulOptimalWriteAlignment: UInt32
    ulMaximumDriveCount: UInt32
    ulStripeSize: UInt32
    ulReserved1: UInt32
    ulReserved2: UInt32
    ulReserved3: UInt32
    bFastCrashRecoveryRequired: win32more.Windows.Win32.Foundation.BOOL
    bMostlyReads: win32more.Windows.Win32.Foundation.BOOL
    bOptimizeForSequentialReads: win32more.Windows.Win32.Foundation.BOOL
    bOptimizeForSequentialWrites: win32more.Windows.Win32.Foundation.BOOL
    bRemapEnabled: win32more.Windows.Win32.Foundation.BOOL
    bReadBackVerifyEnabled: win32more.Windows.Win32.Foundation.BOOL
    bWriteThroughCachingEnabled: win32more.Windows.Win32.Foundation.BOOL
    bHardwareChecksumEnabled: win32more.Windows.Win32.Foundation.BOOL
    bIsYankable: win32more.Windows.Win32.Foundation.BOOL
    bAllocateHotSpare: win32more.Windows.Win32.Foundation.BOOL
    bUseMirroredCache: win32more.Windows.Win32.Foundation.BOOL
    bReadCachingEnabled: win32more.Windows.Win32.Foundation.BOOL
    bWriteCachingEnabled: win32more.Windows.Win32.Foundation.BOOL
    bMediaScanEnabled: win32more.Windows.Win32.Foundation.BOOL
    bConsistencyCheckEnabled: win32more.Windows.Win32.Foundation.BOOL
    BusType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    bReserved1: win32more.Windows.Win32.Foundation.BOOL
    bReserved2: win32more.Windows.Win32.Foundation.BOOL
    bReserved3: win32more.Windows.Win32.Foundation.BOOL
    sRebuildPriority: Int16
VDS_HWPROVIDER_TYPE = Int32
VDS_HWT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 0
VDS_HWT_PCI_RAID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 1
VDS_HWT_FIBRE_CHANNEL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 2
VDS_HWT_ISCSI: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 3
VDS_HWT_SAS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 4
VDS_HWT_HYBRID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE = 5
class VDS_INPUT_DISK(Structure):
    diskId: Guid
    ullSize: UInt64
    plexId: Guid
    memberIdx: UInt32
class VDS_INTERCONNECT(Structure):
    m_addressType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE
    m_cbPort: UInt32
    m_pbPort: POINTER(Byte)
    m_cbAddress: UInt32
    m_pbAddress: POINTER(Byte)
VDS_INTERCONNECT_ADDRESS_TYPE = Int32
VDS_IA_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 0
VDS_IA_FCFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 1
VDS_IA_FCPH: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 2
VDS_IA_FCPH3: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 3
VDS_IA_MAC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 4
VDS_IA_SCSI: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_ADDRESS_TYPE = 5
VDS_INTERCONNECT_FLAG = Int32
VDS_ITF_PCI_RAID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_FLAG = 1
VDS_ITF_FIBRE_CHANNEL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_FLAG = 2
VDS_ITF_ISCSI: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_FLAG = 4
VDS_ITF_SAS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT_FLAG = 8
class VDS_IPADDRESS(Structure):
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS_TYPE
    ipv4Address: UInt32
    ipv6Address: Byte * 16
    ulIpv6FlowInfo: UInt32
    ulIpv6ScopeId: UInt32
    wszTextAddress: Char * 257
    ulPort: UInt32
VDS_IPADDRESS_TYPE = Int32
VDS_IPT_TEXT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS_TYPE = 0
VDS_IPT_IPV4: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS_TYPE = 1
VDS_IPT_IPV6: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS_TYPE = 2
VDS_IPT_EMPTY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS_TYPE = 3
VDS_ISCSI_AUTH_TYPE = Int32
VDS_IAT_NONE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_AUTH_TYPE = 0
VDS_IAT_CHAP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_AUTH_TYPE = 1
VDS_IAT_MUTUAL_CHAP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_AUTH_TYPE = 2
class VDS_ISCSI_INITIATOR_ADAPTER_PROP(Structure):
    id: Guid
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
class VDS_ISCSI_INITIATOR_PORTAL_PROP(Structure):
    id: Guid
    address: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS
    ulPortIndex: UInt32
VDS_ISCSI_IPSEC_FLAG = Int32
VDS_IIF_VALID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 1
VDS_IIF_IKE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 2
VDS_IIF_MAIN_MODE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 4
VDS_IIF_AGGRESSIVE_MODE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 8
VDS_IIF_PFS_ENABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 16
VDS_IIF_TRANSPORT_MODE_PREFERRED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 32
VDS_IIF_TUNNEL_MODE_PREFERRED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_IPSEC_FLAG = 64
class VDS_ISCSI_IPSEC_KEY(Structure):
    pKey: POINTER(Byte)
    ulKeySize: UInt32
VDS_ISCSI_LOGIN_FLAG = Int32
VDS_ILF_REQUIRE_IPSEC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_FLAG = 1
VDS_ILF_MULTIPATH_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_FLAG = 2
VDS_ISCSI_LOGIN_TYPE = Int32
VDS_ILT_MANUAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_TYPE = 0
VDS_ILT_PERSISTENT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_TYPE = 1
VDS_ILT_BOOT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_LOGIN_TYPE = 2
class VDS_ISCSI_PORTALGROUP_PROP(Structure):
    id: Guid
    tag: UInt16
class VDS_ISCSI_PORTAL_PROP(Structure):
    id: Guid
    address: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS
VDS_ISCSI_PORTAL_STATUS = Int32
VDS_IPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS = 0
VDS_IPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS = 1
VDS_IPS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS = 2
VDS_IPS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS = 4
VDS_IPS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_ISCSI_PORTAL_STATUS = 5
class VDS_ISCSI_SHARED_SECRET(Structure):
    pSharedSecret: POINTER(Byte)
    ulSharedSecretSize: UInt32
class VDS_ISCSI_TARGET_PROP(Structure):
    id: Guid
    pwszIscsiName: win32more.Windows.Win32.Foundation.PWSTR
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    bChapEnabled: win32more.Windows.Win32.Foundation.BOOL
VDS_LOADBALANCE_POLICY_ENUM = Int32
VDS_LBP_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 0
VDS_LBP_FAILOVER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 1
VDS_LBP_ROUND_ROBIN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 2
VDS_LBP_ROUND_ROBIN_WITH_SUBSET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 3
VDS_LBP_DYN_LEAST_QUEUE_DEPTH: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 4
VDS_LBP_WEIGHTED_PATHS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 5
VDS_LBP_LEAST_BLOCKS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 6
VDS_LBP_VENDOR_SPECIFIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LOADBALANCE_POLICY_ENUM = 7
VDS_LUN_FLAG = Int32
VDS_LF_LBN_REMAP_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 1
VDS_LF_READ_BACK_VERIFY_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 2
VDS_LF_WRITE_THROUGH_CACHING_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 4
VDS_LF_HARDWARE_CHECKSUM_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 8
VDS_LF_READ_CACHE_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 16
VDS_LF_WRITE_CACHE_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 32
VDS_LF_MEDIA_SCAN_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 64
VDS_LF_CONSISTENCY_CHECK_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 128
VDS_LF_SNAPSHOT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_FLAG = 256
class VDS_LUN_INFORMATION(Structure):
    m_version: UInt32
    m_DeviceType: Byte
    m_DeviceTypeModifier: Byte
    m_bCommandQueueing: win32more.Windows.Win32.Foundation.BOOL
    m_BusType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    m_szVendorId: POINTER(Byte)
    m_szProductId: POINTER(Byte)
    m_szProductRevision: POINTER(Byte)
    m_szSerialNumber: POINTER(Byte)
    m_diskSignature: Guid
    m_deviceIdDescriptor: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_DEVICE_ID_DESCRIPTOR
    m_cInterconnects: UInt32
    m_rgInterconnects: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_INTERCONNECT)
class VDS_LUN_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_LUN
    LunId: Guid
VDS_LUN_PLEX_FLAG = Int32
VDS_LPF_LBN_REMAP_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_FLAG = 1
class VDS_LUN_PLEX_PROP(Structure):
    id: Guid
    ullSize: UInt64
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    TransitionState: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE
    ulFlags: UInt32
    ulStripeSize: UInt32
    sRebuildPriority: Int16
VDS_LUN_PLEX_STATUS = Int32
VDS_LPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS = 0
VDS_LPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS = 1
VDS_LPS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS = 2
VDS_LPS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS = 4
VDS_LPS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_STATUS = 5
VDS_LUN_PLEX_TYPE = Int32
VDS_LPT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 0
VDS_LPT_SIMPLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 10
VDS_LPT_SPAN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 11
VDS_LPT_STRIPE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 12
VDS_LPT_PARITY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 14
VDS_LPT_RAID2: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 15
VDS_LPT_RAID3: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 16
VDS_LPT_RAID4: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 17
VDS_LPT_RAID5: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 18
VDS_LPT_RAID6: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 19
VDS_LPT_RAID03: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 21
VDS_LPT_RAID05: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 22
VDS_LPT_RAID10: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 23
VDS_LPT_RAID15: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 24
VDS_LPT_RAID30: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 25
VDS_LPT_RAID50: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 26
VDS_LPT_RAID53: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 28
VDS_LPT_RAID60: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_PLEX_TYPE = 29
class VDS_LUN_PROP(Structure):
    id: Guid
    ullSize: UInt64
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    pwszUnmaskingList: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    TransitionState: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE
    sRebuildPriority: Int16
VDS_LUN_RESERVE_MODE = Int32
VDS_LRM_NONE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE = 0
VDS_LRM_EXCLUSIVE_RW: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE = 1
VDS_LRM_EXCLUSIVE_RO: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE = 2
VDS_LRM_SHARED_RO: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE = 3
VDS_LRM_SHARED_RW: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_RESERVE_MODE = 4
VDS_LUN_STATUS = Int32
VDS_LS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS = 0
VDS_LS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS = 1
VDS_LS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS = 2
VDS_LS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS = 4
VDS_LS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_STATUS = 5
VDS_LUN_TYPE = Int32
VDS_LT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 0
VDS_LT_DEFAULT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 1
VDS_LT_FAULT_TOLERANT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 2
VDS_LT_NON_FAULT_TOLERANT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 3
VDS_LT_SIMPLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 10
VDS_LT_SPAN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 11
VDS_LT_STRIPE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 12
VDS_LT_MIRROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 13
VDS_LT_PARITY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 14
VDS_LT_RAID2: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 15
VDS_LT_RAID3: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 16
VDS_LT_RAID4: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 17
VDS_LT_RAID5: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 18
VDS_LT_RAID6: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 19
VDS_LT_RAID01: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 20
VDS_LT_RAID03: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 21
VDS_LT_RAID05: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 22
VDS_LT_RAID10: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 23
VDS_LT_RAID15: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 24
VDS_LT_RAID30: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 25
VDS_LT_RAID50: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 26
VDS_LT_RAID51: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 27
VDS_LT_RAID53: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 28
VDS_LT_RAID60: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 29
VDS_LT_RAID61: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_TYPE = 30
VDS_MAINTENANCE_OPERATION = Int32
BlinkLight: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION = 1
BeepAlarm: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION = 2
SpinDown: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION = 3
SpinUp: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION = 4
Ping: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MAINTENANCE_OPERATION = 5
class VDS_MOUNT_POINT_NOTIFICATION(Structure):
    ulEvent: UInt32
    volumeId: Guid
VDS_NF_CONTROLLER = UInt32
VDS_NF_CONTROLLER_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_CONTROLLER = 103
VDS_NF_CONTROLLER_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_CONTROLLER = 104
VDS_NF_CONTROLLER_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_CONTROLLER = 350
VDS_NF_CONTROLLER_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_CONTROLLER = 351
VDS_NF_DISK = UInt32
VDS_NF_DISK_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DISK = 8
VDS_NF_DISK_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DISK = 9
VDS_NF_DISK_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DISK = 10
VDS_NF_DRIVE = UInt32
VDS_NF_DRIVE_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DRIVE = 105
VDS_NF_DRIVE_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DRIVE = 106
VDS_NF_DRIVE_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DRIVE = 107
VDS_NF_DRIVE_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_DRIVE = 354
VDS_NF_FILE_SYSTEM = UInt32
VDS_NF_FILE_SYSTEM_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_FILE_SYSTEM = 203
VDS_NF_FILE_SYSTEM_FORMAT_PROGRESS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_FILE_SYSTEM = 204
VDS_NF_LUN = UInt32
VDS_NF_LUN_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_LUN = 108
VDS_NF_LUN_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_LUN = 109
VDS_NF_LUN_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_LUN = 110
VDS_NF_PACK = UInt32
VDS_NF_PACK_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PACK = 1
VDS_NF_PACK_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PACK = 2
VDS_NF_PACK_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PACK = 3
VDS_NF_PORT = UInt32
VDS_NF_PORT_ARRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PORT = 121
VDS_NF_PORT_DEPART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PORT = 122
VDS_NF_PORT_MODIFY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PORT = 352
VDS_NF_PORT_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PORT = 353
class VDS_NOTIFICATION(Structure):
    objectType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Pack: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_NOTIFICATION
        Disk: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DISK_NOTIFICATION
        Volume: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_NOTIFICATION
        Partition: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_NOTIFICATION
        Letter: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_LETTER_NOTIFICATION
        FileSystem: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_NOTIFICATION
        MountPoint: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_MOUNT_POINT_NOTIFICATION
        SubSystem: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_NOTIFICATION
        Controller: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_CONTROLLER_NOTIFICATION
        Drive: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_DRIVE_NOTIFICATION
        Lun: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_LUN_NOTIFICATION
        Port: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_NOTIFICATION
        Portal: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORTAL_NOTIFICATION
        Target: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TARGET_NOTIFICATION
        PortalGroup: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORTAL_GROUP_NOTIFICATION
        Service: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_NOTIFICATION
VDS_NOTIFICATION_TARGET_TYPE = Int32
VDS_NTT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 0
VDS_NTT_PACK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 10
VDS_NTT_VOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 11
VDS_NTT_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 13
VDS_NTT_PARTITION: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 60
VDS_NTT_DRIVE_LETTER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 61
VDS_NTT_FILE_SYSTEM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 62
VDS_NTT_MOUNT_POINT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 63
VDS_NTT_SUB_SYSTEM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 30
VDS_NTT_CONTROLLER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 31
VDS_NTT_DRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 32
VDS_NTT_LUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 33
VDS_NTT_PORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 35
VDS_NTT_PORTAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 36
VDS_NTT_TARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 37
VDS_NTT_PORTAL_GROUP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 38
VDS_NTT_SERVICE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NOTIFICATION_TARGET_TYPE = 200
VDS_OBJECT_TYPE = Int32
VDS_OT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 0
VDS_OT_PROVIDER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 1
VDS_OT_PACK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 10
VDS_OT_VOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 11
VDS_OT_VOLUME_PLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 12
VDS_OT_DISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 13
VDS_OT_SUB_SYSTEM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 30
VDS_OT_CONTROLLER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 31
VDS_OT_DRIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 32
VDS_OT_LUN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 33
VDS_OT_LUN_PLEX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 34
VDS_OT_PORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 35
VDS_OT_PORTAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 36
VDS_OT_TARGET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 37
VDS_OT_PORTAL_GROUP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 38
VDS_OT_STORAGE_POOL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 39
VDS_OT_HBAPORT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 90
VDS_OT_INIT_ADAPTER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 91
VDS_OT_INIT_PORTAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 92
VDS_OT_ASYNC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 100
VDS_OT_ENUM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 101
VDS_OT_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 200
VDS_OT_OPEN_VDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_OBJECT_TYPE = 201
VDS_PACK_FLAG = Int32
VDS_PKF_FOREIGN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_FLAG = 1
VDS_PKF_NOQUORUM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_FLAG = 2
VDS_PKF_POLICY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_FLAG = 4
VDS_PKF_CORRUPTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_FLAG = 8
VDS_PKF_ONLINE_ERROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_FLAG = 16
class VDS_PACK_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PACK
    packId: Guid
class VDS_PACK_PROP(Structure):
    id: Guid
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_STATUS
    ulFlags: UInt32
VDS_PACK_STATUS = Int32
VDS_PS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_STATUS = 0
VDS_PS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_STATUS = 1
VDS_PS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PACK_STATUS = 4
VDS_PARTITION_FLAG = Int32
VDS_PTF_SYSTEM: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_FLAG = 1
class VDS_PARTITION_INFORMATION_EX(Structure):
    dwPartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.__VDS_PARTITION_STYLE
    ullStartingOffset: UInt64
    ullPartitionLength: UInt64
    dwPartitionNumber: UInt32
    bRewritePartition: win32more.Windows.Win32.Foundation.BOOLEAN
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_INFO_MBR
        Gpt: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_INFO_GPT
class VDS_PARTITION_INFO_GPT(Structure):
    partitionType: Guid
    partitionId: Guid
    attributes: UInt64
    name: Char * 36
class VDS_PARTITION_INFO_MBR(Structure):
    partitionType: Byte
    bootIndicator: win32more.Windows.Win32.Foundation.BOOLEAN
    recognizedPartition: win32more.Windows.Win32.Foundation.BOOLEAN
    hiddenSectors: UInt32
class VDS_PARTITION_NOTIFICATION(Structure):
    ulEvent: UInt32
    diskId: Guid
    ullOffset: UInt64
class VDS_PARTITION_PROP(Structure):
    PartitionStyle: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE
    ulFlags: UInt32
    ulPartitionNumber: UInt32
    ullOffset: UInt64
    ullSize: UInt64
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Mbr: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_INFO_MBR
        Gpt: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_INFO_GPT
VDS_PARTITION_STYLE = Int32
VDS_PST_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE = 0
VDS_PST_MBR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE = 1
VDS_PST_GPT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PARTITION_STYLE = 2
class VDS_PATH_ID(Structure):
    ullSourceId: UInt64
    ullPathId: UInt64
class VDS_PATH_INFO(Structure):
    pathId: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_ID
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HWPROVIDER_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        controllerPortId: Guid
        targetPortalId: Guid
    class _Anonymous2_e__Union(Union):
        hbaPortId: Guid
        initiatorAdapterId: Guid
    class _Anonymous3_e__Union(Union):
        pHbaPortProp: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HBAPORT_PROP)
        pInitiatorPortalIpAddr: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_IPADDRESS)
class VDS_PATH_POLICY(Structure):
    pathId: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_ID
    bPrimaryPath: win32more.Windows.Win32.Foundation.BOOL
    ulWeight: UInt32
VDS_PATH_STATUS = Int32
VDS_MPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS = 0
VDS_MPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS = 1
VDS_MPS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS = 5
VDS_MPS_STANDBY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PATH_STATUS = 7
class VDS_POOL_ATTRIBUTES(Structure):
    ullAttributeMask: UInt64
    raidType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE
    busType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE
    pwszIntendedUsage: win32more.Windows.Win32.Foundation.PWSTR
    bSpinDown: win32more.Windows.Win32.Foundation.BOOL
    bIsThinProvisioned: win32more.Windows.Win32.Foundation.BOOL
    ullProvisionedSpace: UInt64
    bNoSinglePointOfFailure: win32more.Windows.Win32.Foundation.BOOL
    ulDataRedundancyMax: UInt32
    ulDataRedundancyMin: UInt32
    ulDataRedundancyDefault: UInt32
    ulPackageRedundancyMax: UInt32
    ulPackageRedundancyMin: UInt32
    ulPackageRedundancyDefault: UInt32
    ulStripeSize: UInt32
    ulStripeSizeMax: UInt32
    ulStripeSizeMin: UInt32
    ulDefaultStripeSize: UInt32
    ulNumberOfColumns: UInt32
    ulNumberOfColumnsMax: UInt32
    ulNumberOfColumnsMin: UInt32
    ulDefaultNumberofColumns: UInt32
    ulDataAvailabilityHint: UInt32
    ulAccessRandomnessHint: UInt32
    ulAccessDirectionHint: UInt32
    ulAccessSizeHint: UInt32
    ulAccessLatencyHint: UInt32
    ulAccessBandwidthWeightHint: UInt32
    ulStorageCostHint: UInt32
    ulStorageEfficiencyHint: UInt32
    ulNumOfCustomAttributes: UInt32
    pPoolCustomAttributes: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_POOL_CUSTOM_ATTRIBUTES)
    bReserved1: win32more.Windows.Win32.Foundation.BOOL
    bReserved2: win32more.Windows.Win32.Foundation.BOOL
    ulReserved1: UInt32
    ulReserved2: UInt32
    ullReserved1: UInt64
    ullReserved2: UInt64
class VDS_POOL_CUSTOM_ATTRIBUTES(Structure):
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszValue: win32more.Windows.Win32.Foundation.PWSTR
class VDS_PORTAL_GROUP_NOTIFICATION(Structure):
    ulEvent: UInt32
    portalGroupId: Guid
class VDS_PORTAL_NOTIFICATION(Structure):
    ulEvent: UInt32
    portalId: Guid
class VDS_PORT_NOTIFICATION(Structure):
    ulEvent: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_NF_PORT
    portId: Guid
class VDS_PORT_PROP(Structure):
    id: Guid
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS
VDS_PORT_STATUS = Int32
VDS_PRS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 0
VDS_PRS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 1
VDS_PRS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 2
VDS_PRS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 4
VDS_PRS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 5
VDS_PRS_REMOVED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PORT_STATUS = 8
VDS_PROVIDER_FLAG = Int32
VDS_PF_DYNAMIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 1
VDS_PF_INTERNAL_HARDWARE_PROVIDER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 2
VDS_PF_ONE_DISK_ONLY_PER_PACK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 4
VDS_PF_ONE_PACK_ONLINE_ONLY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 8
VDS_PF_VOLUME_SPACE_MUST_BE_CONTIGUOUS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 16
VDS_PF_SUPPORT_DYNAMIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = -2147483648
VDS_PF_SUPPORT_FAULT_TOLERANT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 1073741824
VDS_PF_SUPPORT_DYNAMIC_1394: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 536870912
VDS_PF_SUPPORT_MIRROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 32
VDS_PF_SUPPORT_RAID5: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_FLAG = 64
VDS_PROVIDER_LBSUPPORT_FLAG = Int32
VDS_LBF_FAILOVER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 1
VDS_LBF_ROUND_ROBIN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 2
VDS_LBF_ROUND_ROBIN_WITH_SUBSET: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 4
VDS_LBF_DYN_LEAST_QUEUE_DEPTH: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 8
VDS_LBF_WEIGHTED_PATHS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 16
VDS_LBF_LEAST_BLOCKS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 32
VDS_LBF_VENDOR_SPECIFIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_LBSUPPORT_FLAG = 64
class VDS_PROVIDER_PROP(Structure):
    id: Guid
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    guidVersionId: Guid
    pwszVersion: win32more.Windows.Win32.Foundation.PWSTR
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE
    ulFlags: UInt32
    ulStripeSizeFlags: UInt32
    sRebuildPriority: Int16
VDS_PROVIDER_TYPE = Int32
VDS_PT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE = 0
VDS_PT_SOFTWARE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE = 1
VDS_PT_HARDWARE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE = 2
VDS_PT_VIRTUALDISK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE = 3
VDS_PT_MAX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_PROVIDER_TYPE = 4
VDS_QUERY_PROVIDER_FLAG = Int32
VDS_QUERY_SOFTWARE_PROVIDERS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_QUERY_PROVIDER_FLAG = 1
VDS_QUERY_HARDWARE_PROVIDERS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_QUERY_PROVIDER_FLAG = 2
VDS_QUERY_VIRTUALDISK_PROVIDERS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_QUERY_PROVIDER_FLAG = 4
VDS_RAID_TYPE = Int32
VDS_RT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 0
VDS_RT_RAID0: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 10
VDS_RT_RAID1: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 11
VDS_RT_RAID2: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 12
VDS_RT_RAID3: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 13
VDS_RT_RAID4: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 14
VDS_RT_RAID5: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 15
VDS_RT_RAID6: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 16
VDS_RT_RAID01: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 17
VDS_RT_RAID03: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 18
VDS_RT_RAID05: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 19
VDS_RT_RAID10: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 20
VDS_RT_RAID15: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 21
VDS_RT_RAID30: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 22
VDS_RT_RAID50: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 23
VDS_RT_RAID51: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 24
VDS_RT_RAID53: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 25
VDS_RT_RAID60: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 26
VDS_RT_RAID61: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RAID_TYPE = 27
VDS_RECOVER_ACTION = Int32
VDS_RA_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RECOVER_ACTION = 0
VDS_RA_REFRESH: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RECOVER_ACTION = 1
VDS_RA_RESTART: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RECOVER_ACTION = 2
class VDS_REPARSE_POINT_PROP(Structure):
    SourceVolumeId: Guid
    pwszPath: win32more.Windows.Win32.Foundation.PWSTR
VDS_SAN_POLICY = Int32
VDS_SP_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 0
VDS_SP_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 1
VDS_SP_OFFLINE_SHARED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 2
VDS_SP_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 3
VDS_SP_OFFLINE_INTERNAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 4
VDS_SP_MAX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SAN_POLICY = 5
VDS_SERVICE_FLAG = Int32
VDS_SVF_SUPPORT_DYNAMIC: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 1
VDS_SVF_SUPPORT_FAULT_TOLERANT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 2
VDS_SVF_SUPPORT_GPT: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 4
VDS_SVF_SUPPORT_DYNAMIC_1394: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 8
VDS_SVF_CLUSTER_SERVICE_CONFIGURED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 16
VDS_SVF_AUTO_MOUNT_OFF: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 32
VDS_SVF_OS_UNINSTALL_VALID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 64
VDS_SVF_EFI: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 128
VDS_SVF_SUPPORT_MIRROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 256
VDS_SVF_SUPPORT_RAID5: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 512
VDS_SVF_SUPPORT_REFS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SERVICE_FLAG = 1024
class VDS_SERVICE_NOTIFICATION(Structure):
    ulEvent: UInt32
    action: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_RECOVER_ACTION
class VDS_SERVICE_PROP(Structure):
    pwszVersion: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
VDS_STORAGE_BUS_TYPE = Int32
VDSBusTypeUnknown: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 0
VDSBusTypeScsi: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 1
VDSBusTypeAtapi: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 2
VDSBusTypeAta: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 3
VDSBusType1394: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 4
VDSBusTypeSsa: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 5
VDSBusTypeFibre: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 6
VDSBusTypeUsb: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 7
VDSBusTypeRAID: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 8
VDSBusTypeiScsi: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 9
VDSBusTypeSas: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 10
VDSBusTypeSata: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 11
VDSBusTypeSd: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 12
VDSBusTypeMmc: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 13
VDSBusTypeMax: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 14
VDSBusTypeVirtual: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 14
VDSBusTypeFileBackedVirtual: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 15
VDSBusTypeSpaces: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 16
VDSBusTypeNVMe: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 17
VDSBusTypeScm: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 18
VDSBusTypeUfs: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 19
VDSBusTypeMaxReserved: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_BUS_TYPE = 127
class VDS_STORAGE_DEVICE_ID_DESCRIPTOR(Structure):
    m_version: UInt32
    m_cIdentifiers: UInt32
    m_rgIdentifiers: POINTER(win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER)
class VDS_STORAGE_IDENTIFIER(Structure):
    m_CodeSet: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_CODE_SET
    m_Type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE
    m_cbIdentifier: UInt32
    m_rgbIdentifier: POINTER(Byte)
VDS_STORAGE_IDENTIFIER_CODE_SET = Int32
VDSStorageIdCodeSetReserved: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_CODE_SET = 0
VDSStorageIdCodeSetBinary: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_CODE_SET = 1
VDSStorageIdCodeSetAscii: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_CODE_SET = 2
VDSStorageIdCodeSetUtf8: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_CODE_SET = 3
VDS_STORAGE_IDENTIFIER_TYPE = Int32
VDSStorageIdTypeVendorSpecific: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 0
VDSStorageIdTypeVendorId: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 1
VDSStorageIdTypeEUI64: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 2
VDSStorageIdTypeFCPHName: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 3
VDSStorageIdTypePortRelative: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 4
VDSStorageIdTypeTargetPortGroup: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 5
VDSStorageIdTypeLogicalUnitGroup: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 6
VDSStorageIdTypeMD5LogicalUnitIdentifier: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 7
VDSStorageIdTypeScsiNameString: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_IDENTIFIER_TYPE = 8
class VDS_STORAGE_POOL_DRIVE_EXTENT(Structure):
    id: Guid
    ullSize: UInt64
    bUsed: win32more.Windows.Win32.Foundation.BOOL
class VDS_STORAGE_POOL_PROP(Structure):
    id: Guid
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_TYPE
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pwszDescription: win32more.Windows.Win32.Foundation.PWSTR
    ullTotalConsumedSpace: UInt64
    ullTotalManagedSpace: UInt64
    ullRemainingFreeSpace: UInt64
VDS_STORAGE_POOL_STATUS = Int32
VDS_SPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_STATUS = 0
VDS_SPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_STATUS = 1
VDS_SPS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_STATUS = 2
VDS_SPS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_STATUS = 4
VDS_STORAGE_POOL_TYPE = Int32
VDS_SPT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_TYPE = 0
VDS_SPT_PRIMORDIAL: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_TYPE = 1
VDS_SPT_CONCRETE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_STORAGE_POOL_TYPE = 2
VDS_SUB_SYSTEM_FLAG = Int32
VDS_SF_LUN_MASKING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 1
VDS_SF_LUN_PLEXING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 2
VDS_SF_LUN_REMAPPING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 4
VDS_SF_DRIVE_EXTENT_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 8
VDS_SF_HARDWARE_CHECKSUM_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 16
VDS_SF_RADIUS_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 32
VDS_SF_READ_BACK_VERIFY_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 64
VDS_SF_WRITE_THROUGH_CACHING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 128
VDS_SF_SUPPORTS_FAULT_TOLERANT_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 512
VDS_SF_SUPPORTS_NON_FAULT_TOLERANT_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 1024
VDS_SF_SUPPORTS_SIMPLE_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 2048
VDS_SF_SUPPORTS_SPAN_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 4096
VDS_SF_SUPPORTS_STRIPE_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 8192
VDS_SF_SUPPORTS_MIRROR_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 16384
VDS_SF_SUPPORTS_PARITY_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 32768
VDS_SF_SUPPORTS_AUTH_CHAP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 65536
VDS_SF_SUPPORTS_AUTH_MUTUAL_CHAP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 131072
VDS_SF_SUPPORTS_SIMPLE_TARGET_CONFIG: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 262144
VDS_SF_SUPPORTS_LUN_NUMBER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 524288
VDS_SF_SUPPORTS_MIRRORED_CACHE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 1048576
VDS_SF_READ_CACHING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 2097152
VDS_SF_WRITE_CACHING_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 4194304
VDS_SF_MEDIA_SCAN_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 8388608
VDS_SF_CONSISTENCY_CHECK_CAPABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_FLAG = 16777216
class VDS_SUB_SYSTEM_NOTIFICATION(Structure):
    ulEvent: UInt32
    subSystemId: Guid
class VDS_SUB_SYSTEM_PROP(Structure):
    id: Guid
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
    ulStripeSizeFlags: UInt32
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    sNumberOfInternalBuses: Int16
    sMaxNumberOfSlotsEachBus: Int16
    sMaxNumberOfControllers: Int16
    sRebuildPriority: Int16
class VDS_SUB_SYSTEM_PROP2(Structure):
    id: Guid
    pwszFriendlyName: win32more.Windows.Win32.Foundation.PWSTR
    pwszIdentification: win32more.Windows.Win32.Foundation.PWSTR
    ulFlags: UInt32
    ulStripeSizeFlags: UInt32
    ulSupportedRaidTypeFlags: UInt32
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    sNumberOfInternalBuses: Int16
    sMaxNumberOfSlotsEachBus: Int16
    sMaxNumberOfControllers: Int16
    sRebuildPriority: Int16
    ulNumberOfEnclosures: UInt32
VDS_SUB_SYSTEM_STATUS = Int32
VDS_SSS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 0
VDS_SSS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 1
VDS_SSS_NOT_READY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 2
VDS_SSS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 4
VDS_SSS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 5
VDS_SSS_PARTIALLY_MANAGED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_STATUS = 9
VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = Int32
VDS_SF_SUPPORTS_RAID2_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 1
VDS_SF_SUPPORTS_RAID3_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 2
VDS_SF_SUPPORTS_RAID4_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 4
VDS_SF_SUPPORTS_RAID5_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 8
VDS_SF_SUPPORTS_RAID6_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 16
VDS_SF_SUPPORTS_RAID01_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 32
VDS_SF_SUPPORTS_RAID03_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 64
VDS_SF_SUPPORTS_RAID05_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 128
VDS_SF_SUPPORTS_RAID10_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 256
VDS_SF_SUPPORTS_RAID15_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 512
VDS_SF_SUPPORTS_RAID30_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 1024
VDS_SF_SUPPORTS_RAID50_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 2048
VDS_SF_SUPPORTS_RAID51_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 4096
VDS_SF_SUPPORTS_RAID53_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 8192
VDS_SF_SUPPORTS_RAID60_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 16384
VDS_SF_SUPPORTS_RAID61_LUNS: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_SUB_SYSTEM_SUPPORTED_RAID_TYPE_FLAG = 32768
class VDS_TARGET_NOTIFICATION(Structure):
    ulEvent: UInt32
    targetId: Guid
VDS_TRANSITION_STATE = Int32
VDS_TS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 0
VDS_TS_STABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 1
VDS_TS_EXTENDING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 2
VDS_TS_SHRINKING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 3
VDS_TS_RECONFIGING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 4
VDS_TS_RESTRIPING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE = 5
class VDS_VDISK_PROPERTIES(Structure):
    Id: Guid
    State: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE
    VirtualDeviceType: win32more.Windows.Win32.Storage.Vhd.VIRTUAL_STORAGE_TYPE
    VirtualSize: UInt64
    PhysicalSize: UInt64
    pPath: win32more.Windows.Win32.Foundation.PWSTR
    pDeviceName: win32more.Windows.Win32.Foundation.PWSTR
    DiskFlag: win32more.Windows.Win32.Storage.Vhd.DEPENDENT_DISK_FLAG
    bIsChild: win32more.Windows.Win32.Foundation.BOOL
    pParentPath: win32more.Windows.Win32.Foundation.PWSTR
VDS_VDISK_STATE = Int32
VDS_VST_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 0
VDS_VST_ADDED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 1
VDS_VST_OPEN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 2
VDS_VST_ATTACH_PENDING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 3
VDS_VST_ATTACHED_NOT_OPEN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 4
VDS_VST_ATTACHED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 5
VDS_VST_DETACH_PENDING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 6
VDS_VST_COMPACTING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 7
VDS_VST_MERGING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 8
VDS_VST_EXPANDING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 9
VDS_VST_DELETED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 10
VDS_VST_MAX: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VDISK_STATE = 11
VDS_VERSION_SUPPORT_FLAG = Int32
VDS_VSF_1_0: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VERSION_SUPPORT_FLAG = 1
VDS_VSF_1_1: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VERSION_SUPPORT_FLAG = 2
VDS_VSF_2_0: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VERSION_SUPPORT_FLAG = 4
VDS_VSF_2_1: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VERSION_SUPPORT_FLAG = 8
VDS_VSF_3_0: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VERSION_SUPPORT_FLAG = 16
VDS_VOLUME_FLAG = Int32
VDS_VF_SYSTEM_VOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 1
VDS_VF_BOOT_VOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 2
VDS_VF_ACTIVE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 4
VDS_VF_READONLY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 8
VDS_VF_HIDDEN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 16
VDS_VF_CAN_EXTEND: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 32
VDS_VF_CAN_SHRINK: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 64
VDS_VF_PAGEFILE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 128
VDS_VF_HIBERNATION: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 256
VDS_VF_CRASHDUMP: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 512
VDS_VF_INSTALLABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 1024
VDS_VF_LBN_REMAP_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 2048
VDS_VF_FORMATTING: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 4096
VDS_VF_NOT_FORMATTABLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 8192
VDS_VF_NTFS_NOT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 16384
VDS_VF_FAT32_NOT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 32768
VDS_VF_FAT_NOT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 65536
VDS_VF_NO_DEFAULT_DRIVE_LETTER: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 131072
VDS_VF_PERMANENTLY_DISMOUNTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 262144
VDS_VF_PERMANENT_DISMOUNT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 524288
VDS_VF_SHADOW_COPY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 1048576
VDS_VF_FVE_ENABLED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 2097152
VDS_VF_DIRTY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 4194304
VDS_VF_REFS_NOT_SUPPORTED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 8388608
VDS_VF_BACKS_BOOT_VOLUME: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 16777216
VDS_VF_BACKED_BY_WIM_IMAGE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_FLAG = 33554432
class VDS_VOLUME_NOTIFICATION(Structure):
    ulEvent: UInt32
    volumeId: Guid
    plexId: Guid
    ulPercentCompleted: UInt32
class VDS_VOLUME_PLEX_PROP(Structure):
    id: Guid
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    TransitionState: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE
    ullSize: UInt64
    ulStripeSize: UInt32
    ulNumberOfMembers: UInt32
VDS_VOLUME_PLEX_STATUS = Int32
VDS_VPS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_STATUS = 0
VDS_VPS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_STATUS = 1
VDS_VPS_NO_MEDIA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_STATUS = 3
VDS_VPS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_STATUS = 5
VDS_VOLUME_PLEX_TYPE = Int32
VDS_VPT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE = 0
VDS_VPT_SIMPLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE = 10
VDS_VPT_SPAN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE = 11
VDS_VPT_STRIPE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE = 12
VDS_VPT_PARITY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_PLEX_TYPE = 14
class VDS_VOLUME_PROP(Structure):
    id: Guid
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    TransitionState: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE
    ullSize: UInt64
    ulFlags: UInt32
    RecommendedFileSystemType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
class VDS_VOLUME_PROP2(Structure):
    id: Guid
    type: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE
    status: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS
    health: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_HEALTH
    TransitionState: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_TRANSITION_STATE
    ullSize: UInt64
    ulFlags: UInt32
    RecommendedFileSystemType: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_FILE_SYSTEM_TYPE
    cbUniqueId: UInt32
    pwszName: win32more.Windows.Win32.Foundation.PWSTR
    pUniqueId: POINTER(Byte)
VDS_VOLUME_STATUS = Int32
VDS_VS_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS = 0
VDS_VS_ONLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS = 1
VDS_VS_NO_MEDIA: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS = 3
VDS_VS_FAILED: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS = 5
VDS_VS_OFFLINE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_STATUS = 4
VDS_VOLUME_TYPE = Int32
VDS_VT_UNKNOWN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 0
VDS_VT_SIMPLE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 10
VDS_VT_SPAN: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 11
VDS_VT_STRIPE: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 12
VDS_VT_MIRROR: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 13
VDS_VT_PARITY: win32more.Windows.Win32.Storage.VirtualDiskService.VDS_VOLUME_TYPE = 14
class VDS_WWN(Structure):
    rguchWwn: Byte * 8
__VDS_PARTITION_STYLE = Int32
VDS_PARTITION_STYLE_MBR: win32more.Windows.Win32.Storage.VirtualDiskService.__VDS_PARTITION_STYLE = 0
VDS_PARTITION_STYLE_GPT: win32more.Windows.Win32.Storage.VirtualDiskService.__VDS_PARTITION_STYLE = 1
VDS_PARTITION_STYLE_RAW: win32more.Windows.Win32.Storage.VirtualDiskService.__VDS_PARTITION_STYLE = 2


make_ready(__name__)
